@charset "UTF-8";
@import url("https://fonts.googleapis.com/css?family=Open+Sans:400,600");
@font-face {
  font-family: 'wcmp';
  src: url("../fonts/wcmp-font.eot?lyp4c7");
  src: url("../fonts/wcmp-font.eot?lyp4c7#iefix") format("embedded-opentype"), url("../fonts/wcmp-font.ttf?lyp4c7") format("truetype"), url("../fonts/wcmp-font.woff?lyp4c7") format("woff");
  font-weight: normal;
  font-style: normal; }
i.wcmp-font {
  /* use !important to prevent issues with browser extensions that change fonts */
  font-family: 'wcmp' !important;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  vertical-align: middle;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale; }

.ico-cancel-status-icon:before {
  content: "\e94f"; }

.ico-completed-status-icon:before {
  content: "\e950"; }

.ico-customer-details-icon:before {
  content: "\e951"; }

.ico-download2-icon:before {
  content: "\e952"; }

.ico-email-invoice-icon:before {
  content: "\e953"; }

.ico-failed-status-icon:before {
  content: "\e954"; }

.ico-order-commission:before {
  content: "\e955"; }

.ico-order-detailsnew-icon:before {
  content: "\e956"; }

.ico-pendingpayment-status-icon:before {
  content: "\e957"; }

.ico-processing-status-icon:before {
  content: "\e958"; }

.ico-refunded-status-icon:before {
  content: "\e959"; }

.ico-resend-notification-icon:before {
  content: "\e95a"; }

.ico-shippingnew2-icon:before {
  content: "\e95b"; }

.ico-duplicate-icon:before {
  content: "\e94e"; }

.ico-back-arrow:before {
  content: "\e94d"; }

.ico-search-icon:before {
  content: "\e94c"; }

.ico-export:before {
  content: "\e91b"; }

.ico-import:before {
  content: "\e921"; }

.ico-message:before {
  content: "\e92b"; }

.ico-notification:before {
  content: "\e930"; }

.ico-quote:before {
  content: "\e937"; }

.ico-rental-calender:before {
  content: "\e940"; }

.ico-resources:before {
  content: "\e941"; }

.ico-subscriptions:before {
  content: "\e94a"; }

.ico-add-booking:before {
  content: "\e94b"; }

.ico-uncheckbox-icon:before {
  content: "\e915"; }

.ico-check-box-icon:before {
  content: "\e90b"; }

.ico-approve-icon:before {
  content: "\e943"; }

.ico-delete-icon:before {
  content: "\e944"; }

.ico-expire-icon:before {
  content: "\e945"; }

.ico-reject-icon:before {
  content: "\e946"; }

.ico-rental-icon:before {
  content: "\e947"; }

.ico-reply-icon:before {
  content: "\e948"; }

.ico-rupee-icon:before {
  content: "\e949"; }

.ico-addcoupon-icon:before {
  content: "\e900"; }

.ico-add-icon:before {
  content: "\e901"; }

.ico-add-product-icon:before {
  content: "\e902"; }

.ico-all-bookings-icon:before {
  content: "\e903"; }

.ico-announcement-icon:before {
  content: "\e904"; }

.ico-avarage-order-value-icon:before {
  content: "\e905"; }

.ico-billing-icon:before {
  content: "\e906"; }

.ico-booking-icon:before {
  content: "\e907"; }

.ico-calendar-icon:before {
  content: "\e908"; }

.ico-cart-icon:before {
  content: "\e909"; }

.ico-catalog-icon:before {
  content: "\e90a"; }

.ico-coupons-icon:before {
  content: "\e90c"; }

.ico-dashboard-icon:before {
  content: "\e90d"; }

.ico-downarrow-2-icon:before {
  content: "\e90e"; }

.ico-down-arrow-icon:before {
  content: "\e90f"; }

.ico-download-icon:before {
  content: "\e910"; }

.ico-earning-icon:before {
  content: "\e911"; }

.ico-edit-pencil-icon:before {
  content: "\e912"; }

.ico-export-icon:before {
  content: "\e913"; }

.ico-eye-icon:before {
  content: "\e914"; }

.ico-history-icon:before {
  content: "\e916"; }

.ico-image-icon:before {
  content: "\e917"; }

.ico-import-icon:before {
  content: "\e918"; }

.ico-knowledgebase-icon:before {
  content: "\e919"; }

.ico-left-arrow-icon:before {
  content: "\e91a"; }

.ico-logout-icon:before {
  content: "\e91c"; }

.ico-minus-icon:before {
  content: "\e91d"; }

.ico-my-shop-icon:before {
  content: "\e91e"; }

.ico-order-details-icon:before {
  content: "\e91f"; }

.ico-orders-icon:before {
  content: "\e920"; }

.ico-payments-icon:before {
  content: "\e922"; }

.ico-pdf-icon:before {
  content: "\e923"; }

.ico-plus-icon:before {
  content: "\e924"; }

.ico-policies-icon:before {
  content: "\e925"; }

.ico-price2-icon:before {
  content: "\e926"; }

.ico-price-icon:before {
  content: "\e927"; }

.ico-product-icon:before {
  content: "\e928"; }

.ico-product-manager-icon:before {
  content: "\e929"; }

.ico-questionmark-icon:before {
  content: "\e92a"; }

.ico-report-icon:before {
  content: "\e92c"; }

.ico-reports-icon:before {
  content: "\e92d"; }

.ico-revenue-icon:before {
  content: "\e92e"; }

.ico-right-arrow-icon:before {
  content: "\e92f"; }

.ico-shipping-action-icon:before {
  content: "\e931"; }

.ico-shipping-icon:before {
  content: "\e932"; }

.ico-shippingnew-icon:before {
  content: "\e933"; }

.ico-storefront-icon:before {
  content: "\e934"; }

.ico-store-settings-icon:before {
  content: "\e935"; }

.ico-tools-icon:before {
  content: "\e936"; }

.ico-uparrow-2-icon:before {
  content: "\e938"; }

.ico-up-arrow-icon:before {
  content: "\e939"; }

.ico-upload-image-icon:before {
  content: "\e93a"; }

.ico-user-icon:before {
  content: "\e93b"; }

.ico-vendor-stuff-icon:before {
  content: "\e93c"; }

.ico-verified-icon:before {
  content: "\e93d"; }

.ico-visit-icon:before {
  content: "\e93e"; }

.ico-welcome-icon:before {
  content: "\e93f"; }

.ico-wp-backend-icon:before {
  content: "\e942"; }

body {
  font-family: "Open Sans", sans-serif;
  color: #626c6f;
  font-size: 14px;
  line-height: 1.3;
  overflow-x: hidden; }

h1 {
  color: #333b3d;
  margin: 0 0 15px;
  font-size: 30px;
  font-weight: 400;
  line-height: 38px; }

h2 {
  color: #202627;
  font-size: 18px;
  margin: 0;
  line-height: 1.3; }

h3 {
  color: #252525;
  font-size: 14px;
  line-height: 22px;
  margin: 0 0 15px; }

h4 {
  color: #525252;
  font-size: 15px;
  margin: 0 0 15px; }

a {
  cursor: pointer;
  color: #3f85b9; }
  a:hover, a:focus, a:active {
    text-decoration: none;
    box-shadow: none;
    outline: none;
    color: #333b3d; }

button:focus {
  outline: none; }

img {
  max-width: 100%;
  height: auto; }

label, .label {
  font-weight: normal;
  color: inherit; }

body textarea.form-control {
  height: 100px;
  overflow-x: hidden; }

select:not([multiple]), select.form-control:not([multiple]) {
  -webkit-appearance: none;
  -moz-appearance: none;
  -ms-appearance: none;
  -o-appearance: none;
  appearance: none;
  padding-right: 27px !important;
  background-image: url("../../images/down-arrow.png");
  background-repeat: no-repeat;
  background-position: right 13px top 50%;
  background-color: #fff;
  padding: 3px 5px 4px;
  box-shadow: none;
  line-height: 20px;
  border: 1px solid #d3dbe2;
  border-radius: 4px;
  height: 34px; }
  select:not([multiple])::-ms-expand, select.form-control:not([multiple])::-ms-expand {
    display: none; }

select[multiple] {
  height: 100px;
  border-color: #d3dbe2; }

.select-wrap {
  position: relative;
  display: inline-block; }
  .select-wrap:after {
    position: absolute;
    content: '\e90c';
    right: 10px;
    top: 50%;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%);
    font-family: 'wcmp' !important;
    color: #737377;
    font-size: 13px; }

.inline-input {
  width: auto;
  display: inline-block;
  vertical-align: middle; }

.verticalAlign, .current-endpoint-title-wrapper .current-endpoint i, .current-endpoint-title-wrapper .current-endpoint span, .wcmp_vendor_products_cust_qna .customer-questions-panel article .media .media-body .qna-date i, .wcmp_vendor_products_cust_qna .customer-questions-panel article .media .media-body .qna-date span, form.stat-date-range .panel-heading h3, form.stat-date-range .panel-heading .form-group {
  display: inline-block;
  vertical-align: middle; }

ul {
  list-style: none;
  padding: 0;
  margin: 0; }

.default-content-css ul {
  display: block;
  list-style-type: disc;
  -webkit-margin-before: 1em;
  -webkit-margin-after: 1em;
  -webkit-margin-start: 0px;
  -webkit-margin-end: 0px;
  -webkit-padding-start: 40px; }
  .default-content-css ul li {
    display: list-item;
    text-align: -webkit-match-parent; }
.default-content-css h1, .default-content-css h2, .default-content-css h3 {
  margin: 0.5em 0; }

@media screen and (max-width: 480px) {
  h1 {
    font-size: 21px;
    line-height: 28px; }

  h2 {
    font-size: 16px; }

  .heading-underline {
    margin-bottom: 25px; } }
.zero-radius {
  border-radius: 0; }

.btm-margin-0 {
  margin-bottom: 0; }

.cover-page-wrap {
  margin: 0 -30px; }

.white-bkg {
  background-color: #fff; }

.light-gray-bkg {
  background: #f7f8fa; }

.gray-bkg {
  background: #edf0f1; }

.content-padding {
  padding: 30px; }
  @media (max-width: 768px) {
    .content-padding {
      padding: 20px; } }
  @media (max-width: 480px) {
    .content-padding {
      padding: 15px; } }

.m-0 {
  margin: 0 !important; }

.p-0 {
  padding: 0 !important; }

.mt-0 {
  margin-top: 0px !important; }

.mt-10 {
  margin-top: 10px !important; }

.mt-15 {
  margin-top: 15px !important; }

.mt-20 {
  margin-top: 20px !important; }

.mb-0 {
  margin-bottom: 0px !important; }

.mb-10 {
  margin-bottom: 10px !important; }

.mb-15 {
  margin-bottom: 15px !important; }

.mb-20 {
  margin-bottom: 20px !important; }

.pt-0 {
  padding-top: 0px !important; }

.pt-10 {
  padding-top: 10px !important; }

.pt-15 {
  padding-top: 15px !important; }

.pt-20 {
  padding-top: 20px !important; }

.pb-0 {
  padding-bottom: 0px !important; }

.pb-10 {
  padding-bottom: 10px !important; }

.pb-15 {
  padding-bottom: 15px !important; }

.pb-20 {
  padding-bottom: 20px !important; }

.border-top {
  border-top: solid 1px #d3dbe2; }

.border {
  border: solid 1px #d3dbe2; }

.border-top {
  border-top: solid 1px #d3dbe2; }

.no-border {
  border: 0; }

span.form-text {
  display: block; }

@media screen and (max-width: 767px) {
  .mt-md-10 {
    margin-top: 10px; }

  .mt-md-15 {
    margin-top: 15px; } }
.full-width {
  width: 100%; }

@media screen and (max-width: 1080px) {
  .full-1080 {
    width: 100% !important; } }
@media screen and (max-width: 768px) {
  .full-768 {
    width: 100% !important; } }
.inp-btm-margin {
  margin-bottom: 15px; }

.overflow-hidden {
  overflow: hidden; }

.overlay {
  position: relative; }
  .overlay:after {
    content: '';
    position: fixed;
    top: 64px;
    left: 0;
    width: 100%;
    height: calc(100vh - 56px);
    background-color: rgba(0, 0, 0, 0.5);
    z-index: 9; }

.action-icon {
  font-size: 19px;
  margin: 0 12px 0 0; }

.pos-rel {
  position: relative; }

.pos-abl {
  position: absolute; }

.pos-ver-middle {
  position: absolute;
  top: 50%;
  -webkit-transform: translateY(-50%);
      -ms-transform: translateY(-50%);
          transform: translateY(-50%); }

.pos-middle {
  position: absolute;
  top: 50%;
  left: 0;
  right: 0;
  margin: auto;
  -webkit-transform: translateY(-50%);
      -ms-transform: translateY(-50%);
          transform: translateY(-50%); }

.heading-underline {
  position: relative;
  margin-bottom: 35px; }
  .heading-underline:after {
    position: absolute;
    content: '';
    width: 57px;
    height: 2px;
    background: #d3d4d5;
    left: 0;
    right: 0;
    margin: auto;
    bottom: -10px; }

.pos-rel {
  position: relative; }

.inline, .inline-top, .single-order-detail-table table .order-item-img, .single-order-detail-table table .order-item-detail, .inline-middle, .change-status .order-status-text i, .change-status .order-status-text span {
  display: inline-block; }

.inline-top, .single-order-detail-table table .order-item-img, .single-order-detail-table table .order-item-detail {
  vertical-align: top; }

.inline-middle, .change-status .order-status-text i, .change-status .order-status-text span {
  vertical-align: middle; }

.wcmp-panel-loader {
  position: absolute;
  width: 100%;
  height: 100%;
  background: rgba(255, 255, 255, 0.7);
  text-align: center;
  z-index: 9;
  display: none; }
  .wcmp-panel-loader .wcmp-spinner {
    z-index: 2;
    color: #232e2e;
    position: absolute;
    top: 50%;
    -webkit-transform: translateY(-50%) translateX(-50%);
        -ms-transform: translateY(-50%) translateX(-50%);
            transform: translateY(-50%) translateX(-50%);
    right: 50%; }

.loaderOverlay {
  position: relative;
  cursor: progress; }

.loaderOverlay:after {
  position: absolute;
  content: '';
  background: rgba(255, 255, 255, 0.6);
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  z-index: 1; }

hr {
  border-color: #d3dbe2; }

.table > tbody > tr > td {
  padding: 20px; }

.table > thead > tr > th {
  padding: 8px 20px; }

.dataTable.table > thead > tr > th {
  padding: 8px; }

.table-striped > tbody > tr:nth-of-type(odd) {
  background-color: #fff; }

table th, table td {
  border-left: none;
  border-right: none;
  border-collapse: collapse; }
table tr {
  background-color: #fff; }
table tbody tr:first-of-type th {
  background: transparent; }
table tbody th, table thead th, table th {
  background-color: #fff;
  font-weight: 400;
  font-family: "Open Sans", sans-serif;
  font-size: 14px;
  border-top: 0;
  color: #000; }
table.table-bordered {
  border: 1px solid #d3dbe2; }
  table.table-bordered tr th {
    position: relative;
    border-right: 0 !important;
    border-left: 0 !important; }
    table.table-bordered tr th:before {
      content: '';
      position: absolute;
      width: 1px;
      height: calc(100% - 12px);
      background: #d3dbe2;
      right: 0;
      top: 0;
      bottom: 0;
      margin: auto;
      z-index: 1; }
    table.table-bordered tr th:last-of-type:before {
      display: none; }
  table.table-bordered.no-th-border tr th:before {
    display: none; }
  table.table-bordered thead th {
    vertical-align: middle; }
@-moz-document url-prefix() {
  table.table-bordered tbody {
    border-top: solid 2px #d3dbe2; } }
table.table-outer-border {
  border: 1px solid #ddd; }
  table.table-outer-border .table-outer-border thead th:last-of-type, table.table-outer-border .table-outer-border tbody td:last-of-type {
    border-right: 1px solid #ddd; }
table input[type="checkbox"] {
  margin: 0 !important; }

.table-bordered > tbody > tr > td, .table-bordered > tbody > tr > th, .table-bordered > tfoot > tr > td, .table-bordered > tfoot > tr > th, .table-bordered > thead > tr > td, .table-bordered > thead > tr > th {
  border: 1px solid #d3dbe2; }

.top-navbar {
  padding-top: 0;
  padding-bottom: 0; }

.breadcrumb {
  background-color: transparent;
  padding: 0;
  margin: 19px 0 0; }
  .breadcrumb a {
    color: #626c6f; }
    .breadcrumb a:hover {
      color: #252525; }
  .breadcrumb .active {
    color: #fff; }

.breadcrumb-panel {
  border-left: 6px solid #3f85b9 !important; }

.panel-body p:last-of-type {
  margin-bottom: 0; }

.panel.panel-default.panel-pading {
  padding: 25px; }
  @media screen and (max-width: 640px) {
    .panel.panel-default.panel-pading {
      padding: 20px; } }
  @media screen and (max-width: 480px) {
    .panel.panel-default.panel-pading {
      padding: 15px; } }

.wcmp_vendor_transaction_details .transaction-details .transaction-list li, .staticstics-panel-wrap .panel-body, .wcmp_vendor_products_cust_qna .customer-questions-panel article, .wcmp_vendor_product_stats .panel-body, .wcmp_customer_reviews .wcmp-comments .media-list tr td {
  padding: 20px }

.wcmp-non-vendor-notice {
  margin-top: 55px; }
  .wcmp-non-vendor-notice p {
    margin: 0; }

input.upload_button, input.remove_button {
  font-size: 14px;
  padding: 10px;
  width: 30%;
  margin-bottom: 0;
  vertical-align: middle !important;
  width: 104px;
  height: 45px;
  border: 2px solid #d2d2d2;
  text-align: left;
  background-color: transparent;
  background-repeat: no-repeat;
  background-position: right 10px center;
  background-size: 22px auto; }

input.upload_button:focus, input.remove_button:focus {
  outline: none; }

input.upload_button:hover, input.remove_button:hover {
  border-color: #bbb5b5; }

input.upload_button {
  background-image: url(../../images/upload-icon.png); }

input.remove_button {
  background-image: url(../../images/delete-icon.png); }

body .mCSB_scrollTools {
  margin: 0 !important;
  width: 8px; }
  body .mCSB_scrollTools .mCSB_draggerRail {
    background: #444e50 !important;
    width: 100%;
    border-radius: 0; }
  body .mCSB_scrollTools .mCSB_dragger_bar {
    background: #0d1114 !important;
    width: 100% !important;
    border-radius: 10px !important;
    margin: 0 !important;
    width: 100% !important; }

.wcmp_shop_settings_form .panel.panel-default:last-of-type, .wcmp_policy_form .panel.panel-default:last-of-type, .col-lg-8 .panel.panel-default:last-of-type, .col-lg-4 .panel.panel-default:last-of-type, .form-inner .panel.panel-default:last-of-type {
  margin-bottom: 0; }

#wrapper {
  width: 100%; }

#page-wrapper {
  min-height: calc(100vh - 64px);
  background: #edf0f1; }

@media (min-width: 769px) {
  #page-wrapper {
    margin: 64px 0 0 284px; } }
.panel.panel-default {
  border: none;
  padding: 18px 20px 20px;
  margin: 35px 0 0;
  border-radius: 0;
  -webkit-transition: all 0.3s;
  transition: all 0.3s; }
  .panel.panel-default .panel-heading {
    color: #252525;
    background-color: transparent;
    border-color: transparent;
    padding: 0 0 12px;
    border-bottom: 1px solid #e6e7e8;
    margin: 0 0 20px;
    overflow: hidden; }
    .panel.panel-default .panel-heading h3 {
      margin: 0; }
    .panel.panel-default .panel-heading h1 {
      margin-bottom: 7px; }
  /* .panel.panel-default .panel-body {
    padding: 0; } */
    .panel.panel-default .panel-body table:last-of-type {
      margin-bottom: 0; }
  .panel.panel-default:hover {
    box-shadow: 1px 1px 6px rgba(0, 0, 0, 0.2); }
  .panel.panel-default .panel-footer {
    margin: 15px -20px 0;
    border-top: 1px solid #e6e7e8;
    padding: 20px 20px 0;
    overflow: hidden;
    background: transparent; }
    .panel.panel-default .panel-footer i {
      font-size: 9px;
      margin: 0 0 2px 0;
      display: inline-block;
      vertical-align: middle; }
  .panel.panel-default.pannel-outer-heading {
    padding: 0;
    background-color: transparent;
    box-shadow: none; }
    .panel.panel-default.pannel-outer-heading .panel-heading {
      border: none;
      padding: 0;
      margin: 0 0 12px; }
    .panel.panel-default.pannel-outer-heading .panel-body {
      background-color: #fff;
      border: 1px solid #d3dbe2;}
    .panel.panel-default.pannel-outer-heading .panel-footer {
      background-color: #fff;
      margin: 0;
      padding: 14px 20px;
      border: 1px solid #d3dbe2;
      border-top: 0; }

.panel-custom {
  border: 1px solid #d3dbe2;
  border-radius: 0; }
  .panel-custom .panel-heading {
    background-color: #eff1f5;
    color: #252525;
    border-bottom: 1px solid #d3dbe2;
    padding: 14px 20px; }
  .panel-custom .panel-body {
    padding: 20px; }

.wcmp_vendor_pending_shipping .panel-body, .wcmp_vendor_product_sales_report .panel-body {
  border: 0 !important; }

mark {
  padding: 0 7px 2px;
  font-weight: 600;
}
#wcmp-vendor-ledger .ref_type mark{
    display: block;
    text-align: center;
}
  mark.mark-green {
    background: #42b64d;
    color: #fff; }
  mark.mark-red {
    background: #e55959;
    color: #fff; }

.card-header {
  font-size: 22px;
  border-bottom: 1px solid #ccc;
  margin-bottom: 15px; }

.woocommerce-message {
  padding: 15px;
  border: 1px solid #d6e9c6;
  border-radius: 4px;
  color: #3c763d !important;
  background-color: #dff0d8;
  margin-bottom: 20px; }

.woocommerce-info {
  padding: 15px;
  border: 1px solid #bce8f1;
  border-radius: 4px;
  color: #31708f;
  background-color: #d9edf7;
  margin-bottom: 20px; }

.message-warning {
  padding: 15px;
  border: 1px solid #faebcc;
  border-radius: 4px;
  color: #8a6d3b;
  background-color: #fcf8e3; }

.woocommerce-error {
  padding: 15px;
  border: 1px solid #ebccd1;
  border-radius: 4px;
  color: #a94442;
  background-color: #f2dede;
  margin-bottom: 20px;
  list-style-type: disc;
  list-style-position: inside; }
  .woocommerce-error:focus {
    outline: none;
    box-shadow: none; }
  .woocommerce-error div {
    display: inline-block;
    vertical-align: top;
    width: auto !important;
    padding: 0; }
  .woocommerce-error li:not(:first-child) {
    margin-top: 5px; }

.notice-wrapper .message-container.container {
  width: 100%; }

.wcmp-action-container {
  position: fixed;
  top: 78px;
  right: 31px;
  z-index: 8; }
  .wcmp-action-container .btn {
    margin-top: 0 !important;
    margin-bottom: 0;
    height: auto;
    float: left;
    margin-left: 10px; }
    .wcmp-action-container .btn i {
      color: #fff;
      font-size: 16px;
      vertical-align: middle;
      margin-right: 5px; }
      .wcmp-action-container .btn i:before {
        color: #fff; }
    @media screen and (max-width: 480px) {
      .wcmp-action-container .btn span {
        font-size: 0; }
      .wcmp-action-container .btn i {
        margin: 0; } }
  @media screen and (max-width: 767px) {
    /* .wcmp-action-container {
      top: 61px;
      right: 20px; } */
      .wcmp-action-container .btn {
        font-size: 12px;
        padding: 3px 9px !important; } }

.add-product #wcmp_auto_suggest_product_title ul {
  padding: 0;
  margin: -1px 0 0;
  font-size: 14px;
  text-align: left;
  list-style: none;
  background-color: #fff;
  background-clip: padding-box;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 4px;
  box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175); }
  .add-product #wcmp_auto_suggest_product_title ul a {
    display: block;
    padding: 5px 20px;
    clear: both;
    color: #333;
    white-space: nowrap; }
    .add-product #wcmp_auto_suggest_product_title ul a:hover {
      background: #202627;
      color: #fff; }
  .add-product #wcmp_auto_suggest_product_title ul li.wcmp_no-suggesion {
    display: block;
    padding: 5px 20px;
    clear: both;
    color: #333;
    white-space: nowrap; }

.nav .open > a, .nav .open > a:focus, .nav .open > a:hover {
  background-color: transparent;
  border-color: transparent; }

.nav > li > a:focus, .nav > li > a:hover {
  text-decoration: none;
  background-color: transparent; }

.navbar-default .navbar-collapse, .navbar-default .navbar-form {
  border: none; }

.tab-content > .active {
  opacity: 1; }

.form-group {
  /* margin-bottom: 20px; */
  overflow: hidden; }
  .form-group label {
    font-weight: 400;
    color: #565656; }
  @media screen and (max-width: 480px) {
    .form-group {
      margin-bottom: 12px; } }

label.nolabel {
  visibility: hidden !important;
  padding: 0 !important;
  height: 0; }

.wcmp_form1 .form-group:last-of-type, .form-group-wrapper .form-group:last-of-type {
  margin-bottom: 0; }

.form-control {
  border-color: #c5c5c5;
  max-width: 100%; }
  @media screen and (max-width: 480px) {
    .form-control {
      height: 30px; } }

.form-control, button, button.button, button.btn, select.input-sm, input {
  padding: 3px 5px 4px;
  box-shadow: none;
  line-height: 20px;
  height: 34px;
  min-height: 34px;}

select.input-sm {
  height: 34px; }

.compare-stat-info select.form-control {
  width: auto; }

.pagination > .active > a, .pagination > .active > a:focus, .pagination > .active > a:hover, .pagination > .active > span, .pagination > .active > span:focus, .pagination > .active > span:hover {
  z-index: 2; }

.btn.btn-default, .btn.btn-secondary {
  color: #fff;
  background-color: #3f85b9;
  border-color: #3f85b9;
  padding: 6px 27px;
  -webkit-transition: all 0.4s;
  transition: all 0.4s;
  border-radius: 1px;
  box-shadow: inset 0 -1px 3px rgba(0, 0, 0, 0.2); 
  line-height:1.2}
  .btn.btn-default:hover, .btn.btn-default:active, .btn.btn-secondary:hover, .btn.btn-secondary:active {
    background-color: #202627;
    border-color: #202627;
    color: #fff;
    outline: none; }
  .btn.btn-default:focus, .btn.btn-default:active:focus, .btn.btn-secondary:focus, .btn.btn-secondary:active:focus {
    outline: none; }
  @media screen and (max-width: 640px) {
    .btn.btn-default, .btn.btn-secondary {
      font-size: 13px;
      padding: 3px 9px; } }
  .btn.btn-default.btn-sm, .btn.btn-secondary.btn-sm {
    font-size: 14px;
    padding: 4px 12px; }

.btn.btn-secondary {
  padding-right: 10px;
  padding-left: 10px; }

.label {
  font-size: inherit; }

.pro_ele_block .form-group:last-of-type, .multi_input_block .form-group:last-of-type {
  margin-bottom: 0; }

.multi_input_block label {
  font-size: 14px; }

textarea {
  resize: none; }

.form-horizontal .control-label {
  position: relative;
  text-align: left;
  padding-top: 6px;
  font-size: 14px;
  line-height: 18px;
  word-wrap: break-word; }
  .form-horizontal .control-label .img_tip {
    position: absolute;
    top: 30%;
    left: 75%;
    margin: 0;}
    /* @media screen and (max-width: 480px) {
      .form-horizontal .control-label .img_tip {
        margin: 7px 0 0 0; } } */
  @media screen and (max-width: 480px) {
    .form-horizontal .control-label {
      font-size: 13px;
      padding-right: 20px; } }
.form-horizontal .form-group .checkbox-holder {
  margin-top: 5px; }
.form-horizontal .form-group input[type="checkbox"] {
  margin-top: 0; }
@media screen and (max-width: 480px) {
  .form-horizontal {
    font-size: 13px; } }

body .select2-container {
  /* width: 100% !important; */
  min-height: 34px !important; }
  body .select2-container .select2-selection.select2-selection--multiple {
    height: auto;
    min-height: 34px;
    width: 100%;
    border: 1px solid #c5c5c5;
    max-height: 76px;
    overflow: auto;
    border-radius: 4px; }
    body .select2-container .select2-selection.select2-selection--multiple .select2-selection__rendered {
      padding: 3px 5px 0; }
      body .select2-container .select2-selection.select2-selection--multiple .select2-selection__rendered .select2-selection__choice {
        padding: 1px 7px;
        font-size: 11px;
        margin: 5px 8px 0 0; }
  body .select2-container .select2-search--inline {
    margin-top: 4px;
    line-height: 18px; }
    body .select2-container .select2-search--inline .select2-search__field {
      margin: 0 !important;
      font-size: 14px !important;
      line-height: 18px;
      padding: 0px; }
  body .select2-container .select2-selection--single {
    height: 34px;
    border: 1px solid #c5c5c5; }
    body .select2-container .select2-selection--single .select2-selection__rendered {
      line-height: 33px !important; }

.woocommerce table.form-table select {
  height: 90px !important;
  padding: 5px; }

.woocommerce-exporter-category {
  border-radius: 4px; }

blockquote {
  background: #fff;
  border-left: 5px solid #3f85b9; }

.pagination {
  margin: 13px 0 13px 20px; }
  .pagination li {
    display: inline-block;
    margin-right: 4px;
    vertical-align: middle; }
    .pagination li a {
      padding: 0 6px;
      border-radius: 0 !important;
      border: 1px solid #d3dbe2; }
    .pagination li.active a {
      background: #3f85b9; }

.modal-title {
  width: calc(100% - 25px);
  display: inline-block;
  vertical-align: top; }

@media (max-width: 768px) {
  .modal-dialog {
    margin: 0 auto; } }
#wcmp-afm-bulk-edit-form .form-group {
  margin-bottom: 10px; }

.star-rating {
  text-align: left;
  font-size: 21px;
  overflow: hidden;
  position: relative;
  height: 1em;
  line-height: 1.2em;
  width: 6em;
  font-family: 'dashicons';
  margin: 0 0 25px;
  float: left; }
  .star-rating:before {
    content: "\f154 \f154 \f154 \f154 \f154";
    color: #ddd;
    float: left;
    top: 0;
    left: 0;
    position: absolute;
    color: #3f85b9; }
  .star-rating span {
    overflow: hidden;
    float: left;
    top: 0;
    left: 0;
    position: absolute;
    padding-top: 1.5em;
    font-weight: normal; }
    .star-rating span:before {
      content: "\f155 \f155 \f155 \f155 \f155";
      color: #888;
      top: 0;
      position: absolute;
      left: 0;
      color: #3f85b9; }

.taxonomy-widget {
  padding: 0;
  margin: 0;
  max-height: 200px;
  overflow: auto; }
  .taxonomy-widget label {
    margin: 0; }
  .taxonomy-widget li {
    margin-top: 13px; }
  .taxonomy-widget ul {
    padding: 0 0 0 15px; }

.panel-body > .taxonomy-widget > li:first-child {
  margin-top: 0; }

.media-body h4.media-heading {
  color: #3f85b9; }
.media-body a {
  color: #3f85b9;
  margin-top: 2px;
  display: inline-block; }
  .media-body a:hover {
    color: #000; }

body .ui-accordion {
  border-bottom: 1px solid #d8d8d8;
  font-size: 14px; }
  body .ui-accordion .ui-accordion-header {
    background: #ececec;
    color: #555555;
    border-radius: 0;
    box-shadow: none !important;
    border: 1px solid #d8d8d8;
    border-width: 1px 1px 0 1px;
    margin: 0;
    padding-top: 12px;
    padding-bottom: 12px;
    font-size: 16px; }
    body .ui-accordion .ui-accordion-header:last-of-type {
      border-bottom-width: 1px; }
    body .ui-accordion .ui-accordion-header.ui-accordion-header-active {
      background: #d8d8d8;
      color: #555555; }
      body .ui-accordion .ui-accordion-header.ui-accordion-header-active:hover {
        background: #d8d8d8; }
    body .ui-accordion .ui-accordion-header:focus {
      outline: none; }
    body .ui-accordion .ui-accordion-header.ui-state-hover {
      background: #e5e5e5; }
  body .ui-accordion .ui-accordion-content {
    border-radius: 0;
    border-color: #d8d8d8;
    border-bottom: none; }
    @media screen and (max-width: 480px) {
      body .ui-accordion .ui-accordion-content {
        padding: 1em 1.2em; } }
    body .ui-accordion .ui-accordion-content:last-of-type {
      border: 1px solid #d8d8d8; }
  @media screen and (max-width: 768px) {
    body .ui-accordion .ui-accordion-header {
      padding-top: 8px;
      padding-bottom: 8px;
      font-size: 14px; } }

#ui-datepicker-div {
  z-index: 9 !important; }

.ui-widget-content {
  color: #626c6f; }

body .ui-widget input, body .ui-widget select, body .ui-widget textarea, body .ui-widget button {
  font-size: 14px; }

body .ui-widget {
  font-size: 14px;
  font-family: "Open Sans", sans-serif;
  color: #626c6f; }

body .mce-btn button, body .mce-ico {
  color: #626c6f; }

.progress {
  height: 27px;
  background-color: #4c4c4c; }
  .progress .progress-bar {
    font-size: 13px;
    line-height: 27px; }
  @media screen and (max-width: 768px) {
    .progress {
      height: 22px; }
      .progress .progress-bar {
        line-height: 19px; } }

ul.category-filter-nav li {
  margin-right: 10px; }
  ul.category-filter-nav li a {
    padding: 0 5px;
    position: relative;
    font-size: 13px; }
    ul.category-filter-nav li a:after {
      position: absolute;
      content: '|';
      top: 0;
      right: 0;
      margin: -1px -10px 0 0;
      color: #696969; }
  ul.category-filter-nav li:last-of-type {
    margin-right: 0; }
    ul.category-filter-nav li:last-of-type a:after {
      content: ''; }

.col-actions i {
  font-size: 17px;
  vertical-align: middle; }

div.dataTables_wrapper div.dataTables_processing {
  box-shadow: 1px 1px 10px #423c3c;
  background: #fff; }

div.dataTables_wrapper div.dataTables_length select {
  margin: 0 10px; }

div.dataTables_wrapper div.dataTables_length select.wcmp_filter_product_cat {
  width: auto;
  margin: 0 0 0 5px; }

div.dataTables_wrapper div.dataTables_length select.wcmp-filter-dtdd {
  width: auto;
  margin: 0; }

html div.dataTables_wrapper div.dataTables_filter input {
  width: 170px;
  max-width: calc(100% - 55px); }

table.dataTable:not(.wcmp-widget-dt) {
  font-size: 13px;
  border-color: #b4c1cc;
  margin: 15px 0 !important; }
  table.dataTable:not(.wcmp-widget-dt) thead th, table.dataTable:not(.wcmp-widget-dt) tfoot th {
    font-size: 14px;
    background-color: #d3dbe2;
    color: #000;
    border-right: solid 1px #b4c1cc !important; }
    table.dataTable:not(.wcmp-widget-dt) thead th:last-of-type, table.dataTable:not(.wcmp-widget-dt) tfoot th:last-of-type {
      border: 0 !important; }
    table.dataTable:not(.wcmp-widget-dt) thead th.price, table.dataTable:not(.wcmp-widget-dt) tfoot th.price {
      min-width: 52px; }
  table.dataTable:not(.wcmp-widget-dt) tbody td {
    padding: 10px;
    border-color: #b4c1cc; }
    table.dataTable:not(.wcmp-widget-dt) tbody td.name > a {
      font-size: 14px;
      font-family: "Open Sans", sans-serif; }
    table.dataTable:not(.wcmp-widget-dt) tbody td.name .row-actions {
      margin-top: 5px; }
      table.dataTable:not(.wcmp-widget-dt) tbody td.name .row-actions span.divider {
        display: inline-block;
        vertical-align: top;
        font-size: 11px;
        color: #8c8c8c;
        font-family: "Open Sans", sans-serif; }
    table.dataTable:not(.wcmp-widget-dt) tbody td.price ins {
      display: block; }

.dtr-details .dtr-title, .dtr-details .dtr-data {
  display: inline-block;
  vertical-align: middle; }

table.dataTable > tbody > tr.child ul.dtr-details {
  width: 100%; }

table.dataTable.table {
  border-collapse: collapse !important; }

table.dataTable > tbody > tr.child ul.dtr-details > li:last-child {
  padding-bottom: 0; }

body table.dataTable.dtr-inline.collapsed > tbody > tr[role="row"] > td:first-child:before, body table.dataTable.dtr-inline.collapsed > tbody > tr[role="row"] > th:first-child:before {
  line-height: 15px; }

table.dataTable tbody td.image img {
  min-width: 25px; }

table.dataTable.dtr-inline.collapsed > thead > tr > th:first-child {
  position: relative;
  padding-left: 33px;
  cursor: pointer; }

@media screen and (max-width: 768px) {
  .vendor-product td.image {
    text-align: center; } }
.content-padding:not(.dashboard) .dataTables_wrapper.dt-bootstrap .dataTables_paginate {
  text-align: right; }
  .content-padding:not(.dashboard) .dataTables_wrapper.dt-bootstrap .dataTables_paginate ul {
    margin: 0; }
  .content-padding:not(.dashboard) .dataTables_wrapper.dt-bootstrap .dataTables_paginate li {
    margin: 0; }
    .content-padding:not(.dashboard) .dataTables_wrapper.dt-bootstrap .dataTables_paginate li.previous a, .content-padding:not(.dashboard) .dataTables_wrapper.dt-bootstrap .dataTables_paginate li.next a {
      border: 1px solid #c5c5c5; }
    .content-padding:not(.dashboard) .dataTables_wrapper.dt-bootstrap .dataTables_paginate li a {
      padding: 5px 20px;
      font-size: 16px;
      margin: 0; }
  @media screen and (max-width: 768px) {
    .content-padding:not(.dashboard) .dataTables_wrapper.dt-bootstrap .dataTables_paginate {
      text-align: center;
      margin-top: 8px; }
      .content-padding:not(.dashboard) .dataTables_wrapper.dt-bootstrap .dataTables_paginate li a {
        padding: 5px 10px;
        font-size: 13px; } }

table.dataTable tbody td.image {
  width: 40px; }
table.dataTable tbody td.name {
  width: 33%; }
table.dataTable tbody td.price {
  max-width: 85px; }
table.dataTable tbody td.stock {
  width: 63px; }
  table.dataTable tbody td.stock .label {
    color: #fff; }
table.dataTable tbody td.date {
  width: 130px; }
table.dataTable tbody td.status {
  width: 70px; }

table.dataTable th.image {
  text-align: center; }
table.dataTable .wcmp-font.ico-image-icon {
  font-size: 22px;
  vertical-align: middle;
  color: #000; }

@media screen and (min-width: 768px) {
  .vendor-product .row-actions {
    visibility: hidden; } }
.vendor-product:hover .row-actions {
  visibility: visible; }

span.delete a {
  color: #a00; }

.product_filters .by_status {
  list-style: none;
  margin: 0;
  padding: 0;
  font-size: 14px;
  color: #666; }

.product_filters li {
  display: inline-block;
  margin: 0;
  padding: 0;
  white-space: nowrap; }

.product_filters li a.current {
  color: #000; }

.product_filters li a.current {
  font-weight: 600;
  border: none; }

.screen-reader-text, .screen-reader-text span, .ui-helper-hidden-accessible {
  border: 0;
  clip: rect(1px, 1px, 1px, 1px);
  -webkit-clip-path: inset(50%);
  clip-path: inset(50%);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
  word-wrap: normal !important; }

#media-attachment-date-filters {
  margin-left: 10px; }

body .media-frame select, body .wp-admin .media-frame select {
  line-height: 21px; }

.date-inp-wrap {
  position: relative;
  display: inline-block;
  vertical-align: middle; }
  .date-inp-wrap:after {
    content: '\e908';
    font-family: 'wcmp' !important;
    font-size: 19px;
    position: absolute;
    right: 10px;
    top: 50%;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%);
    color: #737377;
    pointer-events: none; }
  .date-inp-wrap:before {
    content: '';
    position: absolute;
    top: 0;
    right: 37px;
    width: 1px;
    height: 100%;
    background: #d3dbe2;
    pointer-events: none; }
  .date-inp-wrap .hasDatepicker {
    padding-right: 40px;
    padding-right: 40px;
    width: 165px;
    padding-left: 15px;
    height: 34px;
    font-size: 14px; }
    /* @media screen and (max-width: 480px) {
      .date-inp-wrap .hasDatepicker {
        width: 123px;
        padding-left: 5px; } } */

.wcmp-modal * {
  box-sizing: border-box; }

.wcmp-modal-dialog {
  position: fixed;
  background: rgba(0, 0, 0, 0.7);
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  z-index: 1000; }

.wcmp-modal-main .wcmp-modal-header h1 {
  margin: 0;
  font-size: 18px;
  font-weight: 700;
  line-height: 1.5em;
  color: #23282d; }

.wcmp-modal .wcmp-modal-content {
  position: fixed;
  background: #fff;
  z-index: 100000;
  left: 50%;
  top: 50%;
  -webkit-transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  max-width: 100%;
  min-width: 500px; }
  @media screen and (max-width: 640px) {
    .wcmp-modal .wcmp-modal-content {
      min-width: auto;
      width: 90%; } }

.wcmp-modal-main {
  padding-bottom: 55px; }

.wcmp-modal-main article, .wcmp-modal-main header {
  display: block;
  position: relative; }

.wcmp-modal-main .wcmp-modal-header {
  height: auto;
  background: #fcfcfc;
  padding: 1em 1.5em;
  border-bottom: 1px solid #ddd; }

.wcmp-modal-main .wcmp-modal-header .modal-close-link {
  cursor: pointer;
  color: #777;
  height: 54px;
  width: 54px;
  padding: 0;
  position: absolute;
  top: 0;
  right: 0;
  text-align: center;
  border: 0;
  border-left: 1px solid #ddd;
  background-color: transparent;
  -webkit-transition: color .1s ease-in-out,background .1s ease-in-out;
  transition: color .1s ease-in-out,background .1s ease-in-out; }

.wcmp-modal-main .wcmp-modal-header .modal-close-link::before {
  font: normal 22px/50px dashicons !important;
  color: #666;
  display: block;
  content: '\f335';
  font-weight: 300; }

.screen-reader-text, .screen-reader-text span, .ui-helper-hidden-accessible {
  border: 0;
  clip: rect(1px, 1px, 1px, 1px);
  -webkit-clip-path: inset(50%);
  clip-path: inset(50%);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
  word-wrap: normal !important; }

.wcmp-modal .wcmp-modal-content article {
  overflow: auto;
  max-height: 72vh; }

.wcmp-modal-main article {
  padding: 1.5em; }

.wcmp-modal-main article p:first-child {
  margin-top: 0; }

.wcmp-modal-main article p {
  margin: 1.5em 0; }

.wcmp-modal .wc-shipping-zone-method-selector .wc-shipping-zone-method-description {
  margin: .75em 1px 0;
  line-height: 1.5em;
  color: #999;
  font-style: italic; }

.wcmp-modal-main footer {
  position: absolute;
  left: 0;
  right: 0;
  bottom: 0;
  z-index: 100;
  padding: 1em 1.5em;
  background: #fcfcfc;
  border-top: 1px solid #dfdfdf;
  box-shadow: 0 -4px 4px -4px rgba(0, 0, 0, 0.1); }

.wcmp-modal-main footer .inner {
  text-align: right;
  line-height: 23px; }

@media screen and (max-width: 768px) {
  .side-collapse.in {
    opacity: 0; } }
.navbar-default {
  border: none;
  position: relative; }

.navbar {
  min-height: auto;
  margin: 0;
  background: transparent; }
  .navbar .topbar-left {
    height: 100%;
    width: 284px;
    background: #3f85b9; }
    @media screen and (max-width: 768px) {
      .navbar .topbar-left {
        width: 120px; } }
    .navbar .topbar-left .toggle-sidemenu, .navbar .topbar-left .site-logo {
      display: inline-block;
      vertical-align: middle; }
    .navbar .topbar-left .site-logo a {
      display: block;
      color: #fff; }
    .navbar .topbar-left .site-logo img {
      max-width: 95%;
      max-height: 45px;
      vertical-align: -webkit-baseline-middle; }

    ul.nav .login-user {
      position: relative;
      width: 100%;
      background: #333b3d;
      text-align: center;
      padding: 20px;
      cursor: pointer; }
  ul.nav .login-user a i {
    font-size: calc(26px - 3px);
    color: #677072;
    vertical-align: middle; }
  ul.nav .login-user a span i {
    font-size: 11px;
    height: auto;
    width: auto;
    color: #626c6f; }
  ul.nav .login-user a:hover i {
    color: #3f85b9; }
  ul.nav .login-user .dropdown-menu.dropdown-user {
    width: 208px;
    padding: 0;
    z-index: 9999;
    border: solid 4px #fff;
    border-radius: 0;
    margin: 1px 26px 0px 0px;
    box-shadow: 0 6px 12px rgb(0 0 0 / 18%);
    right: 0; }
  ul.nav .login-user .dropdown-menu.dropdown-user a {
    font-size: 13px;
    display: block;
    color: rgb(51, 51, 51);
    padding: 7px 15px;
    margin: 0px;
  }
  ul.nav .login-user .dropdown-menu.dropdown-user a:hover {
    background-color: transparent;
    color: #3f85b9; 
  }
  ul.nav .login-user .dropdown-menu.dropdown-user a:focus {
    background: none; 
  }
  ul.nav .login-user .dropdown-menu.dropdown-user i {
    font-size: 22px;
    vertical-align: middle;
    display: inline-block;
    margin-right: 12px; 
  }
  ul.nav .login-user .dropdown-menu.dropdown-user i + span {
    vertical-align: middle;
    display: inline-block; 
  }
  ul.nav .login-user .dropdown-menu.dropdown-user li:not(.sidebar-logo) {
    margin: 5px 0; 
  }
    @media screen and (max-width: 768px) {
      ul.nav .login-user .dropdown-menu.dropdown-user {
        width: 185px;
        min-width: 160px;
      }
      ul.nav .login-user .dropdown-menu.dropdown-user i {
        font-size: 15px;
        margin-right: 6px; 
        } 
     }

.navbar-top-links {
  margin-right: 0; }
  .navbar-top-links li {
    display: inline-block; }
    .navbar-top-links li.login-user {
      margin-left: 18px;
      position: relative;
      padding-left: 20px; }
      .navbar-top-links li.login-user:before {
        content: '';
        height: 100%;
        width: 1px;
        position: absolute;
        top: 0;
        left: 0;
        background-color: #f1f3f6; }
      .navbar-top-links li.login-user .dropdown-menu.dropdown-user {
        min-width: 225px;
        padding: 0 0 8px; }
    .navbar-top-links li a {
      color: #677072;
      position: relative;
      padding: 10px;
      min-height: 50px;
      -webkit-transition: all 0.3s;
      transition: all 0.3s; }
      .navbar-top-links li a:hover {
        color: #3f85b9; }
      .navbar-top-links li a i {
        font-size: 26px;
        color: #737373;
        display: inline-block;
        vertical-align: middle;
        margin-right: 6px; }
      .navbar-top-links li a span {
        display: inline-block;
        vertical-align: middle;
        font-size: 15px;
        text-transform: capitalize; }
    .navbar-top-links li.notification-link {
      margin: 0 40px 0 0; }
      .navbar-top-links li.notification-link a {
        padding: 0;
        min-height: auto;
        display: inline-block;
        min-height: initial; }
        .navbar-top-links li.notification-link a:hover {
          color: #3f85b9; }
          .navbar-top-links li.notification-link a:hover i {
            color: #3f85b9; }
      .navbar-top-links li.notification-link .notification-blink {
        position: absolute;
        background-color: #e61818;
        border-radius: 23px;
        min-width: 20px;
        min-height: 20px;
        top: -13px;
        left: 14px;
        text-align: center;
        color: #fff;
        padding: 1px 4px;
        width: auto;
        box-shadow: 1px 1px 3px rgba(0, 0, 0, 0.3);
        pointer-events: none; }
  .navbar-top-links .login-user span {
    vertical-align: middle;
    margin-left: 2px; }
    .navbar-top-links .login-user span i {
      font-size: 13px;
      margin: 3px 0 0;
      line-height: 13px;
      width: auto;
      height: auto; }
  .navbar-top-links .login-user a.dropdown-toggle {
    margin-top: 5px;
    padding: 18px 0 23px; }
  .navbar-top-links.nav > li > a:hover, .navbar-top-links.nav > li > a:focus {
    background: transparent; }
  .navbar-top-links.nav .open a, .navbar-top-links.nav .open a:focus, .navbar-top-links.nav .open a:hover {
    background-color: transparent; }
  @media screen and (min-width: 992px) and (max-width: 1200px) {
    .navbar-top-links {
      margin-top: 21px; }
      .navbar-top-links li.notification-link {
        margin: 0 20px 0 0; }
        .navbar-top-links li.notification-link span {
          font-size: 14px; }
        .navbar-top-links li.notification-link i.wcmp-font {
          font-size: 23px; } }

.top-user-nav {
  height: 100%;
  width: 100px; }
  .top-user-nav > li {
    height: 100%; }
    .top-user-nav > li a.dropdown-toggle {
      /* height: 100%;
      padding: 21px;
      width:100px;
      background: #202627;
      text-align: center;  */
    }
      .top-user-nav > li a.dropdown-toggle i.ico-user-icon {
        color: #fff; }
      .top-user-nav > li a.dropdown-toggle span i {
        color: #6d7677;
        margin-left: 7px; }
      .top-user-nav > li a.dropdown-toggle:active, .top-user-nav > li a.dropdown-toggle:hover, .top-user-nav > li a.dropdown-toggle:focus {
        background: transparent }
  @media screen and (max-width: 768px) {
    .top-user-nav {
      width: 78px; } 
      .navbar-top-links .notification-link span {
        font-size: 0px;}}}

.btm-nav-fixed {
  margin-top: 19px; }
  @media screen and (max-width: 768px) {
    .btm-nav-fixed {
      margin-top: 7px; } }

.navbar-top-links .dropdown-menu li {
  display: block; }

.navbar-top-links .dropdown-menu li:last-child {
  margin-right: 0; }

.navbar-top-links .dropdown-menu li a {
  padding: 3px 20px;
  min-height: 0; }

.navbar-top-links .dropdown-menu li a div {
  white-space: normal; }

.navbar-top-links .dropdown-messages,
.navbar-top-links .dropdown-tasks,
.navbar-top-links .dropdown-alerts {
  width: 310px;
  min-width: 0; }

.navbar-top-links .dropdown-messages {
  margin-left: 5px; }

.navbar-top-links .dropdown-tasks {
  margin-left: -59px; }

.navbar-top-links .dropdown-alerts {
  margin-left: -123px; }

.navbar-top-links .dropdown-user {
  right: 0;
  left: auto; }

.sidebar {
  color: #9a9a9a;
  background-color: #333b3d;
  height: calc(100vh - 64px); }
  .sidebar .sidebar-nav.navbar-collapse {
    padding-left: 0;
    padding-right: 0; }
  .sidebar.navbar-default li:not(:first-of-type) {
    margin-top: 1px; }
    @media screen and (max-width: 768px) {
      .sidebar.navbar-default li:not(:first-of-type) {
        margin-top: 2px; } }
  .sidebar.navbar-default a {
    color: inherit;
    padding: 14px 55px 14px 35px;
    font-size: 15px;
    line-height: 1;
    position: relative; }
  .sidebar.navbar-default ul a i {
    font-size: 22px;
    vertical-align: middle;
    margin-right: 9px;
    color: inherit; }
    @media screen and (max-width: 768px) {
      .sidebar.navbar-default ul a i {
        font-size: 18px;
        margin-right: 5px; } }
  .sidebar.navbar-default ul a:hover i, .sidebar.navbar-default ul a.active i {
    color: #3f85b9; }
  .sidebar.navbar-default ul li a i + span {
    vertical-align: middle; }
  .sidebar .mCustomScrollbar {
    height: calc(100vh - 64px); }

.sidebar-logo {
  padding: 14px;
  background-color: #d3dbe2; }
  .sidebar-logo h4 {
    color: inherit;
    font-weight: 500;
    color: #455053;
    margin: 12px 0 0;
    text-transform: uppercase;
    word-wrap: break-word; }
  .sidebar-logo a {
    padding: 0;
    font-size: 13px; }
    .sidebar-logo a:hover, .sidebar-logo a:focus, .sidebar-logo a:active {
      background: transparent !important;
      color: #2eb1f7 !important; }
  .sidebar-logo .vendor-profile-pic-holder {
    position: relative;
    display: inline-block;
    max-width: 90%; }
    .sidebar-logo .vendor-profile-pic-holder img {
      max-height: 100%;
      max-height: 80px; }

.navbar-default.sidebar ul li a.active, .navbar-default.sidebar a:hover, .navbar-default.sidebar a:focus {
  background-color: #202627;
  color: #fff; }

.navbar-default.sidebar ul ul li a {
  padding: 10px 30px 10px 85px;
  color: #aeb2b7;
  text-transform: none; }
  @media screen and (max-width: 768px) {
    .navbar-default.sidebar ul ul li a {
      padding-left: 45px; } }

.navbar-default.sidebar ul ul li a:hover, .navbar-default.sidebar ul ul li a:focus {
  color: #fff;
  background-color: transparent !important; }

.navbar-default.sidebar ul ul li a.active {
  color: #fff;
  background: transparent !important; }

.navbar-default.sidebar ul ul {
  margin-top: 5px;
  margin-bottom: 15px; }

.sidebar.navbar-default ul a i.ico-downarrow-2-icon {
  float: right;
  margin-top: 2px;
  font-size: 14px;
  line-height: 22px;
  margin: 0 8px 0 0;
  position: absolute;
  right: 16px; }
  @media screen and (max-width: 768px) {
    .sidebar.navbar-default ul a i.ico-downarrow-2-icon {
      font-size: 11px;
      right: 10px; } }

.sidebar .submenu li,
.sidebar .nav-third-level li {
  border-bottom: none !important;
  margin-top: 5px; }

.sidebar .submenu li a {
  padding-left: 51px; }

.sidebar .nav-third-level li a {
  padding-left: 52px; }

@media (min-width: 769px) {
  #wrapper {
    position: relative; }

  .sidebar {
    z-index: 1;
    position: absolute;
    width: 284px; }

  .navbar-top-links .dropdown-messages,
  .navbar-top-links .dropdown-tasks,
  .navbar-top-links .dropdown-alerts {
    margin-left: auto; } }
#wrapper {
  overflow-x: hidden; }

#page-wrapper {
  -webkit-transition: all .4s;
  transition: all .4s; }

#page-wrapper.large {
  margin-left: 0; }

.side-collapse-container {
  position: relative;
  left: 0;
  -webkit-transition: left .4s;
  transition: left .4s;
  overflow-x: hidden; }

.side-collapse-container.out {
  left: 284px; }

.side-collapse {
  width: 284px;
  top: 0;
  bottom: 0;
  left: 0;
  position: absolute;
  -webkit-transition: left .4s;
  transition: left .4s; }

.side-collapse.in {
  left: -284px; }

.hasmenu ul {
  display: none; }

  .navbar-default .navbar-toggle:hover {
    background: transparent !important; }
  @media screen and (max-width: 768px) {
    .navbar-default .navbar-toggle {
      height: 56px;
      left: 120px;
      top: -56px; } }

@media screen and (max-width: 768px) {
  #page-wrapper {
    padding-bottom: 44px; }

  .btm-nav-fixed.nav {
    position: fixed;
    width: 100%;
    background: #fff;
    left: 0;
    bottom: 0;
    z-index: 9999;
    padding: 4px 0;
    text-align: center;
    box-shadow: 1px 0 3px rgba(0, 0, 0, 0.2);
    margin: 0; }
    .btm-nav-fixed.nav li {
      margin: 0;
      width: 25%;
      float: left;
      text-align: center; }

  .navbar .topbar-left .site-logo img {
    max-height: 36px; }

  ul.nav .login-user a {
    padding: 0}

  .sidebar.navbar-default a {
    font-size: 12px;
    padding: 12px 26px 12px 12px; }

  .side-collapse {
    width: 200px;
    height: calc(100vh - 56px);
    overflow: auto; }

  .navbar-default.sidebar ul ul li a {
    padding-top: 8px;
    padding-bottom: 8px;
    font-size: 13px; }

  .sidebar .submenu li, .sidebar .nav-third-level li {
    margin-top: 3px; }

  .navbar-default.sidebar ul ul {
    margin-top: 1px;
    margin-bottom: 5px; }

  .sidebar .submenu li a {
    padding-left: 49px; }

  /* ul.nav .login-user .dropdown-menu.dropdown-user {
    min-width: 160px; } */

  .sidebar-logo .vendor-profile-pic-holder {
    width: 80px;
    height: 80px; }

  .sidebar-logo h4 {
    font-size: 12px; }

  ul.nav .login-user .dropdown-menu.dropdown-user a {
    font-size: 13px;
    padding: 1px 10px; }

  #page-wrapper.large {
    position: relative;
    left: 200px; } }
.current-endpoint-title-wrapper {
  height: 65px;
  background-color: #d3dbe2;
  padding: 15px 30px;
  position: fixed;
  width: 100%;
  left: 284px;
  top: 64px;
  z-index: 3;
  -webkit-transition: all 0.4s;
  transition: all 0.4s; }
  .current-endpoint-title-wrapper .current-endpoint {
    display: inline-block;
    margin-top: 5px;
    color: #333b3d;
    font-size: 18px; }
    .current-endpoint-title-wrapper .current-endpoint i {
      margin-right: 10px;
      font-size: 21px; }
  .current-endpoint-title-wrapper + .content-padding {
    padding-top: 94px; }
  @media screen and (max-width: 768px) {
    .current-endpoint-title-wrapper {
      padding: 8px 20px;
      width: 100%;
      height: 38px;
      left: 0; }
      .current-endpoint-title-wrapper .current-endpoint {
        font-size: 14px;
        margin-top: 0; }
      .current-endpoint-title-wrapper + .content-padding {
        padding-top: 114px; } }

.side-collapse-container.large .current-endpoint-title-wrapper {
  left: 0; }
.side-collapse-container.overlay .current-endpoint-title-wrapper {
  min-width: 300px; }
  @media screen and (max-width: 768px) {
    .side-collapse-container.overlay .current-endpoint-title-wrapper {
      left: 200px; } }

.top-navbar {
  position: fixed;
  z-index: 9;
  width: 100%;
  top: 0;
  height: 64px;
  box-shadow: 1px 3px 4px rgba(0, 0, 0, 0.1); }
  
  .top-navbar .navbar {
    height: 100%; }

.navbar-static-top {
  position: fixed;
  top: 64px; }
  @media screen and (max-width: 768px) {
    .navbar-static-top {
      top: 56px;
      z-index: 99;
    }
    .top-order-note td {
      padding: 2px 0 12px;
    }
    /* .vorder-info-top-left table tbody tr {
      display: flex;
      flex-direction: column;
    }  */
  }
body.admin-bar .top-navbar {
  top: 32px; }
body.admin-bar .current-endpoint-title-wrapper, body.admin-bar .navbar-static-top {
  top: 96px; }
body.admin-bar .wcmp-action-container {
  top: 110px; }
@media screen and (max-width: 782px) {
  body.admin-bar #wpadminbar {
    position: fixed; }
  body.admin-bar .top-navbar {
    top: 46px; }

  body.admin-bar .current-endpoint-title-wrapper, body.admin-bar .navbar-static-top {
    top: 102px; }
  body.admin-bar .wcmp-action-container {
    top: 107px; } }

.wcmp-color-scheme-outer_space_blue .navbar .topbar-left,
.wcmp-color-scheme-outer_space_blue .navbar-default .navbar-toggle .icon-bar,
.wcmp-color-scheme-outer_space_blue .staticstics-panel-wrap .panel-body .compare-stat-info:after,
.wcmp-color-scheme-outer_space_blue .progress-bar,
.wcmp-color-scheme-outer_space_blue table.dataTable.dtr-inline.collapsed > tbody > tr[role="row"] > td:first-child:before,
.wcmp-color-scheme-outer_space_blue table.dataTable.dtr-inline.collapsed > tbody > tr[role="row"] > th:first-child:before,
.wcmp-color-scheme-outer_space_blue input[type=radio]:checked:before {
  background: #3f85b9; }
.wcmp-color-scheme-outer_space_blue .navbar-default.sidebar ul li a.active,
.wcmp-color-scheme-outer_space_blue .navbar-default.sidebar a:hover,
.wcmp-color-scheme-outer_space_blue .navbar-default.sidebar a:focus {
  background-color: #202528;
  color: #fff; }
.wcmp-color-scheme-outer_space_blue .sidebar {
  background: #333b3d;
  color: #bcb7b2; }
  .wcmp-color-scheme-outer_space_blue .sidebar a.active i {
    color: #e9e4e0; }
.wcmp-color-scheme-outer_space_blue .vendor-cover-wrap .cover-pic-button button,
.wcmp-color-scheme-outer_space_blue .vendor-cover-wrap .vendor-profile-pic-wraper .profile-pic-btn,
.wcmp-color-scheme-outer_space_blue .woocommerce-exporter-wrapper .button, .wcmp-color-scheme-outer_space_blue .woocommerce-importer-wrapper .button, .wcmp-color-scheme-outer_space_blue .woocommerce-progress-form-wrapper .button {
  color: #fff;
  background-color: #3f85b9;
  border-color: #3f85b9; }
.wcmp-color-scheme-outer_space_blue .btn.btn-default {
  color: #fff;
  background-color: #316fa8;
  border-color: #316fa8; }
.wcmp-color-scheme-outer_space_blue .btn.btn-secondary {
  color: #fff;
  background-color: #333b3d;
  border-color: #333b3d;
  margin-right:5px;
  height: 34px; }
.wcmp-color-scheme-outer_space_blue .pagination li.active a {
  background: #3f85b9;
  border-color: #3f85b9;  
  color: #fff; }
.wcmp-color-scheme-outer_space_blue a, .wcmp-color-scheme-outer_space_blue .media-body a {
  color: #3f85b9; }
  .wcmp-color-scheme-outer_space_blue a:hover, .wcmp-color-scheme-outer_space_blue .media-body a:hover {
    color: #333b3d; }
.wcmp-color-scheme-outer_space_blue .sidebar.navbar-default ul a:hover i,
.wcmp-color-scheme-outer_space_blue .sidebar.navbar-default ul a.active i,
.wcmp-color-scheme-outer_space_blue .sidebar.navbar-default ul a:hover i,
.wcmp-color-scheme-outer_space_blue .sidebar.navbar-default ul a.active i,
.wcmp-color-scheme-outer_space_blue .navbar-top-links li.notification-link a:hover,
.wcmp-color-scheme-outer_space_blue .navbar-top-links li.notification-link a:hover i,
.wcmp-color-scheme-outer_space_blue .navbar-top-links li a:hover,
.wcmp-color-scheme-outer_space_blue ul.nav .login-user a:hover i,
.wcmp-color-scheme-outer_space_blue ul.nav .login-user .dropdown-menu.dropdown-user a:hover,
.wcmp-color-scheme-outer_space_blue .staticstics-panel-wrap .panel-body .stat-detail-info i,
.wcmp-color-scheme-outer_space_blue .staticstics-panel-wrap .panel-body .compare-stat-info:after,
.wcmp-color-scheme-outer_space_blue .transaction-list,
.wcmp-color-scheme-outer_space_blue .product-import.wcmp_displaybox2m h3, .wcmp-color-scheme-outer_space_blue .wcmp_displaybox2 h3,
.wcmp-color-scheme-outer_space_blue input[type=checkbox]:checked:before {
  color: #3f85b9; }
.wcmp-color-scheme-outer_space_blue .wcmp_vendor_transaction_details {
  color: #fff; }
  .wcmp-color-scheme-outer_space_blue .wcmp_vendor_transaction_details .panel-body {
    background: #3f85b9 !important; }
  .wcmp-color-scheme-outer_space_blue .wcmp_vendor_transaction_details .panel-footer {
    background: #316fa8 !important; }
    .wcmp-color-scheme-outer_space_blue .wcmp_vendor_transaction_details .panel-footer a {
      color: #fff; }
.wcmp-color-scheme-outer_space_blue .staticstics-panel-wrap .panel-body > h2,
.wcmp-color-scheme-outer_space_blue .top-user-nav > li a.dropdown-toggle,
.wcmp-color-scheme-outer_space_blue table.dataTable.dtr-inline.collapsed > tbody > tr.parent > td:first-child:before, .wcmp-color-scheme-outer_space_blue table.dataTable.dtr-inline.collapsed > tbody > tr.parent > th:first-child:before {
  background: #333b3d; }
.wcmp-color-scheme-outer_space_blue .woocommerce-exporter-wrapper .wc-progress-steps li.active, .wcmp-color-scheme-outer_space_blue .woocommerce-importer-wrapper .wc-progress-steps li.active, .wcmp-color-scheme-outer_space_blue .woocommerce-progress-form-wrapper .wc-progress-steps li.active {
  border-color: #3f85b9 !important;
  color: #3f85b9 !important; }
  .wcmp-color-scheme-outer_space_blue .woocommerce-exporter-wrapper .wc-progress-steps li.active::before, .wcmp-color-scheme-outer_space_blue .woocommerce-importer-wrapper .wc-progress-steps li.active::before, .wcmp-color-scheme-outer_space_blue .woocommerce-progress-form-wrapper .wc-progress-steps li.active::before {
    border-color: #3f85b9 !important; }
.wcmp-color-scheme-outer_space_blue .current-stat-report {
  color: #316fa8;
  background: rgba(49, 111, 168, 0.15); }
.wcmp-color-scheme-outer_space_blue .product-tab-nav-holder ul li.active a, .wcmp-color-scheme-outer_space_blue .product-tab-nav-holder ul li.active a:hover, .wcmp-color-scheme-outer_space_blue .product-tab-nav-holder ul li.active a:focus {
  border-top-color: #3f85b9; }
.wcmp-color-scheme-outer_space_blue .primary-color {
  color: #3f85b9; }

.wcmp-color-scheme-green_lagoon .navbar .topbar-left,
.wcmp-color-scheme-green_lagoon .navbar-default .navbar-toggle .icon-bar,
.wcmp-color-scheme-green_lagoon .staticstics-panel-wrap .panel-body .compare-stat-info:after,
.wcmp-color-scheme-green_lagoon .progress-bar,
.wcmp-color-scheme-green_lagoon table.dataTable.dtr-inline.collapsed > tbody > tr[role="row"] > td:first-child:before,
.wcmp-color-scheme-green_lagoon table.dataTable.dtr-inline.collapsed > tbody > tr[role="row"] > th:first-child:before,
.wcmp-color-scheme-green_lagoon input[type=radio]:checked:before {
  background: #009788; }
.wcmp-color-scheme-green_lagoon .navbar-default.sidebar ul li a.active,
.wcmp-color-scheme-green_lagoon .navbar-default.sidebar a:hover,
.wcmp-color-scheme-green_lagoon .navbar-default.sidebar a:focus {
  background-color: #171717;
  color: #fff; }
.wcmp-color-scheme-green_lagoon .sidebar {
  background: #212121;
  color: #bcb7b2; }
  .wcmp-color-scheme-green_lagoon .sidebar a.active i {
    color: #e9e4e0; }
.wcmp-color-scheme-green_lagoon .vendor-cover-wrap .cover-pic-button button,
.wcmp-color-scheme-green_lagoon .vendor-cover-wrap .vendor-profile-pic-wraper .profile-pic-btn,
.wcmp-color-scheme-green_lagoon .woocommerce-exporter-wrapper .button, .wcmp-color-scheme-green_lagoon .woocommerce-importer-wrapper .button, .wcmp-color-scheme-green_lagoon .woocommerce-progress-form-wrapper .button {
  color: #fff;
  background-color: #009788;
  border-color: #009788; }
.wcmp-color-scheme-green_lagoon .btn.btn-default {
  color: #fff;
  background-color: #00796a;
  border-color: #00796a; }
.wcmp-color-scheme-green_lagoon .btn.btn-secondary {
  color: #fff;
  background-color: #212121;
  border-color: #212121; }
.wcmp-color-scheme-green_lagoon .pagination li.active a {
  background: #009788;
  border-color: #009788; }
.wcmp-color-scheme-green_lagoon a, .wcmp-color-scheme-green_lagoon .media-body a {
  color: #00796a; }
  .wcmp-color-scheme-green_lagoon a:hover, .wcmp-color-scheme-green_lagoon .media-body a:hover {
    color: #212121; }
.wcmp-color-scheme-green_lagoon .sidebar.navbar-default ul a:hover i,
.wcmp-color-scheme-green_lagoon .sidebar.navbar-default ul a.active i,
.wcmp-color-scheme-green_lagoon .sidebar.navbar-default ul a:hover i,
.wcmp-color-scheme-green_lagoon .sidebar.navbar-default ul a.active i,
.wcmp-color-scheme-green_lagoon .navbar-top-links li.notification-link a:hover,
.wcmp-color-scheme-green_lagoon .navbar-top-links li.notification-link a:hover i,
.wcmp-color-scheme-green_lagoon .navbar-top-links li a:hover,
.wcmp-color-scheme-green_lagoon ul.nav .login-user a:hover i,
.wcmp-color-scheme-green_lagoon ul.nav .login-user .dropdown-menu.dropdown-user a:hover,
.wcmp-color-scheme-green_lagoon .staticstics-panel-wrap .panel-body .stat-detail-info i,
.wcmp-color-scheme-green_lagoon .staticstics-panel-wrap .panel-body .compare-stat-info:after,
.wcmp-color-scheme-green_lagoon .transaction-list,
.wcmp-color-scheme-green_lagoon .product-import.wcmp_displaybox2m h3, .wcmp-color-scheme-green_lagoon .wcmp_displaybox2 h3,
.wcmp-color-scheme-green_lagoon input[type=checkbox]:checked:before {
  color: #009788; }
.wcmp-color-scheme-green_lagoon .wcmp_vendor_transaction_details {
  color: #fff; }
  .wcmp-color-scheme-green_lagoon .wcmp_vendor_transaction_details .panel-body {
    background: #009788 !important; }
  .wcmp-color-scheme-green_lagoon .wcmp_vendor_transaction_details .panel-footer {
    background: #00796a !important; }
    .wcmp-color-scheme-green_lagoon .wcmp_vendor_transaction_details .panel-footer a {
      color: #fff; }
.wcmp-color-scheme-green_lagoon .staticstics-panel-wrap .panel-body > h2,
.wcmp-color-scheme-green_lagoon .top-user-nav > li a.dropdown-toggle,
.wcmp-color-scheme-green_lagoon table.dataTable.dtr-inline.collapsed > tbody > tr.parent > td:first-child:before, .wcmp-color-scheme-green_lagoon table.dataTable.dtr-inline.collapsed > tbody > tr.parent > th:first-child:before {
  background: #212121; }
.wcmp-color-scheme-green_lagoon .woocommerce-exporter-wrapper .wc-progress-steps li.active, .wcmp-color-scheme-green_lagoon .woocommerce-importer-wrapper .wc-progress-steps li.active, .wcmp-color-scheme-green_lagoon .woocommerce-progress-form-wrapper .wc-progress-steps li.active {
  border-color: #009788 !important;
  color: #009788 !important; }
  .wcmp-color-scheme-green_lagoon .woocommerce-exporter-wrapper .wc-progress-steps li.active::before, .wcmp-color-scheme-green_lagoon .woocommerce-importer-wrapper .wc-progress-steps li.active::before, .wcmp-color-scheme-green_lagoon .woocommerce-progress-form-wrapper .wc-progress-steps li.active::before {
    border-color: #009788 !important; }
.wcmp-color-scheme-green_lagoon .current-stat-report {
  color: #00796a;
  background: rgba(0, 121, 106, 0.2); }
.wcmp-color-scheme-green_lagoon .product-tab-nav-holder ul li.active a, .wcmp-color-scheme-green_lagoon .product-tab-nav-holder ul li.active a:hover, .wcmp-color-scheme-green_lagoon .product-tab-nav-holder ul li.active a:focus {
  border-top-color: #009788; }
.wcmp-color-scheme-green_lagoon .primary-color {
  color: #009788; }

.wcmp-color-scheme-old_west .navbar .topbar-left,
.wcmp-color-scheme-old_west .navbar-default .navbar-toggle .icon-bar,
.wcmp-color-scheme-old_west .staticstics-panel-wrap .panel-body .compare-stat-info:after,
.wcmp-color-scheme-old_west .progress-bar,
.wcmp-color-scheme-old_west table.dataTable.dtr-inline.collapsed > tbody > tr[role="row"] > td:first-child:before,
.wcmp-color-scheme-old_west table.dataTable.dtr-inline.collapsed > tbody > tr[role="row"] > th:first-child:before,
.wcmp-color-scheme-old_west input[type=radio]:checked:before {
  background: #c7a589; }
.wcmp-color-scheme-old_west .navbar-default.sidebar ul li a.active,
.wcmp-color-scheme-old_west .navbar-default.sidebar a:hover,
.wcmp-color-scheme-old_west .navbar-default.sidebar a:focus {
  background-color: #46403c;
  color: #fff; }
.wcmp-color-scheme-old_west .sidebar {
  background: #59524c;
  color: #bcb7b2; }
  .wcmp-color-scheme-old_west .sidebar a.active i {
    color: #e9e4e0; }
.wcmp-color-scheme-old_west .vendor-cover-wrap .cover-pic-button button,
.wcmp-color-scheme-old_west .vendor-cover-wrap .vendor-profile-pic-wraper .profile-pic-btn,
.wcmp-color-scheme-old_west .woocommerce-exporter-wrapper .button, .wcmp-color-scheme-old_west .woocommerce-importer-wrapper .button, .wcmp-color-scheme-old_west .woocommerce-progress-form-wrapper .button {
  color: #fff;
  background-color: #c7a589;
  border-color: #c7a589; }
.wcmp-color-scheme-old_west .btn.btn-default {
  color: #fff;
  background-color: #ad8162;
  border-color: #ad8162; }
.wcmp-color-scheme-old_west .btn.btn-secondary {
  color: #fff;
  background-color: #59524c;
  border-color: #59524c; }
.wcmp-color-scheme-old_west .pagination li.active a {
  background: #c7a589;
  border-color: #c7a589; }
.wcmp-color-scheme-old_west a, .wcmp-color-scheme-old_west .media-body a {
  color: #9b6b47; }
  .wcmp-color-scheme-old_west a:hover, .wcmp-color-scheme-old_west .media-body a:hover {
    color: #59524c; }
.wcmp-color-scheme-old_west .sidebar.navbar-default ul a:hover i,
.wcmp-color-scheme-old_west .sidebar.navbar-default ul a.active i,
.wcmp-color-scheme-old_west .sidebar.navbar-default ul a:hover i,
.wcmp-color-scheme-old_west .sidebar.navbar-default ul a.active i,
.wcmp-color-scheme-old_west .navbar-top-links li.notification-link a:hover,
.wcmp-color-scheme-old_west .navbar-top-links li.notification-link a:hover i,
.wcmp-color-scheme-old_west .navbar-top-links li a:hover,
.wcmp-color-scheme-old_west ul.nav .login-user a:hover i,
.wcmp-color-scheme-old_west ul.nav .login-user .dropdown-menu.dropdown-user a:hover,
.wcmp-color-scheme-old_west .staticstics-panel-wrap .panel-body .stat-detail-info i,
.wcmp-color-scheme-old_west .staticstics-panel-wrap .panel-body .compare-stat-info:after,
.wcmp-color-scheme-old_west .transaction-list,
.wcmp-color-scheme-old_west .product-import.wcmp_displaybox2m h3, .wcmp-color-scheme-old_west .wcmp_displaybox2 h3,
.wcmp-color-scheme-old_west input[type=checkbox]:checked:before {
  color: #c7a589; }
.wcmp-color-scheme-old_west .wcmp_vendor_transaction_details {
  color: #000; }
  .wcmp-color-scheme-old_west .wcmp_vendor_transaction_details .panel-body {
    background: #c7a589 !important; }
  .wcmp-color-scheme-old_west .wcmp_vendor_transaction_details .panel-footer {
    background: #ad8162 !important; }
    .wcmp-color-scheme-old_west .wcmp_vendor_transaction_details .panel-footer a {
      color: #fff; }
.wcmp-color-scheme-old_west .staticstics-panel-wrap .panel-body > h2,
.wcmp-color-scheme-old_west .top-user-nav > li a.dropdown-toggle,
.wcmp-color-scheme-old_west table.dataTable.dtr-inline.collapsed > tbody > tr.parent > td:first-child:before, .wcmp-color-scheme-old_west table.dataTable.dtr-inline.collapsed > tbody > tr.parent > th:first-child:before {
  background: #59524c; }
.wcmp-color-scheme-old_west .woocommerce-exporter-wrapper .wc-progress-steps li.active, .wcmp-color-scheme-old_west .woocommerce-importer-wrapper .wc-progress-steps li.active, .wcmp-color-scheme-old_west .woocommerce-progress-form-wrapper .wc-progress-steps li.active {
  border-color: #c7a589 !important;
  color: #c7a589 !important; }
  .wcmp-color-scheme-old_west .woocommerce-exporter-wrapper .wc-progress-steps li.active::before, .wcmp-color-scheme-old_west .woocommerce-importer-wrapper .wc-progress-steps li.active::before, .wcmp-color-scheme-old_west .woocommerce-progress-form-wrapper .wc-progress-steps li.active::before {
    border-color: #c7a589 !important; }
.wcmp-color-scheme-old_west .current-stat-report {
  color: #9b6b47;
  background: rgba(199, 165, 137, 0.3); }
.wcmp-color-scheme-old_west .product-tab-nav-holder ul li.active a, .wcmp-color-scheme-old_west .product-tab-nav-holder ul li.active a:hover, .wcmp-color-scheme-old_west .product-tab-nav-holder ul li.active a:focus {
  border-top-color: #c7a589; }
.wcmp-color-scheme-old_west .primary-color {
  color: #c7a589; }

.wcmp-color-scheme-wild_watermelon .navbar .topbar-left,
.wcmp-color-scheme-wild_watermelon .navbar-default .navbar-toggle .icon-bar,
.wcmp-color-scheme-wild_watermelon .staticstics-panel-wrap .panel-body .compare-stat-info:after,
.wcmp-color-scheme-wild_watermelon .progress-bar,
.wcmp-color-scheme-wild_watermelon input[type=radio]:checked:before {
  background: #fd5668; }
.wcmp-color-scheme-wild_watermelon .navbar-default.sidebar ul li a.active,
.wcmp-color-scheme-wild_watermelon .navbar-default.sidebar a:hover,
.wcmp-color-scheme-wild_watermelon .navbar-default.sidebar a:focus {
  background-color: #353130;
  color: #fff; }
.wcmp-color-scheme-wild_watermelon .sidebar {
  background: #181617;
  color: #bcb7b2; }
  .wcmp-color-scheme-wild_watermelon .sidebar a.active i {
    color: #e9e4e0; }
.wcmp-color-scheme-wild_watermelon .vendor-cover-wrap .cover-pic-button button,
.wcmp-color-scheme-wild_watermelon .vendor-cover-wrap .vendor-profile-pic-wraper .profile-pic-btn,
.wcmp-color-scheme-wild_watermelon .woocommerce-exporter-wrapper .button, .wcmp-color-scheme-wild_watermelon .woocommerce-importer-wrapper .button, .wcmp-color-scheme-wild_watermelon .woocommerce-progress-form-wrapper .button {
  color: #fff;
  background-color: #fd5668;
  border-color: #fd5668; }
.wcmp-color-scheme-wild_watermelon .btn.btn-default {
  color: #fff;
  background-color: #fb3f4e;
  border-color: #fb3f4e; }
.wcmp-color-scheme-wild_watermelon .btn.btn-secondary {
  color: #fff;
  background-color: #181617;
  border-color: #181617; }
.wcmp-color-scheme-wild_watermelon .pagination li.active a {
  background: #fd5668;
  border-color: #fd5668; }
.wcmp-color-scheme-wild_watermelon a, .wcmp-color-scheme-wild_watermelon .media-body a {
  color: #fb3f4e; }
  .wcmp-color-scheme-wild_watermelon a:hover, .wcmp-color-scheme-wild_watermelon .media-body a:hover {
    color: #181617; }
.wcmp-color-scheme-wild_watermelon .sidebar.navbar-default ul a:hover i,
.wcmp-color-scheme-wild_watermelon .sidebar.navbar-default ul a.active i,
.wcmp-color-scheme-wild_watermelon .sidebar.navbar-default ul a:hover i,
.wcmp-color-scheme-wild_watermelon .sidebar.navbar-default ul a.active i,
.wcmp-color-scheme-wild_watermelon .navbar-top-links li.notification-link a:hover,
.wcmp-color-scheme-wild_watermelon .navbar-top-links li.notification-link a:hover i,
.wcmp-color-scheme-wild_watermelon .navbar-top-links li a:hover,
.wcmp-color-scheme-wild_watermelon ul.nav .login-user a:hover i,
.wcmp-color-scheme-wild_watermelon ul.nav .login-user .dropdown-menu.dropdown-user a:hover,
.wcmp-color-scheme-wild_watermelon .staticstics-panel-wrap .panel-body .stat-detail-info i,
.wcmp-color-scheme-wild_watermelon .staticstics-panel-wrap .panel-body .compare-stat-info:after,
.wcmp-color-scheme-wild_watermelon .transaction-list,
.wcmp-color-scheme-wild_watermelon .product-import.wcmp_displaybox2m h3, .wcmp-color-scheme-wild_watermelon .wcmp_displaybox2 h3,
.wcmp-color-scheme-wild_watermelon input[type=checkbox]:checked:before {
  color: #fd5668; }
.wcmp-color-scheme-wild_watermelon .wcmp_vendor_transaction_details {
  color: #fff; }
  .wcmp-color-scheme-wild_watermelon .wcmp_vendor_transaction_details .panel-body {
    background: #fd5668 !important; }
  .wcmp-color-scheme-wild_watermelon .wcmp_vendor_transaction_details .panel-footer {
    background: #fb3f4e !important; }
    .wcmp-color-scheme-wild_watermelon .wcmp_vendor_transaction_details .panel-footer a {
      color: #fff; }
.wcmp-color-scheme-wild_watermelon .staticstics-panel-wrap .panel-body > h2,
.wcmp-color-scheme-wild_watermelon .top-user-nav > li a.dropdown-toggle {
  background: #181617; }
.wcmp-color-scheme-wild_watermelon .woocommerce-exporter-wrapper .wc-progress-steps li.active, .wcmp-color-scheme-wild_watermelon .woocommerce-importer-wrapper .wc-progress-steps li.active, .wcmp-color-scheme-wild_watermelon .woocommerce-progress-form-wrapper .wc-progress-steps li.active {
  border-color: #fd5668 !important;
  color: #fd5668 !important; }
  .wcmp-color-scheme-wild_watermelon .woocommerce-exporter-wrapper .wc-progress-steps li.active::before, .wcmp-color-scheme-wild_watermelon .woocommerce-importer-wrapper .wc-progress-steps li.active::before, .wcmp-color-scheme-wild_watermelon .woocommerce-progress-form-wrapper .wc-progress-steps li.active::before {
    border-color: #fd5668 !important; }
.wcmp-color-scheme-wild_watermelon .current-stat-report {
  color: #fb3f4e;
  background: rgba(251, 63, 78, 0.2); }
.wcmp-color-scheme-wild_watermelon .product-tab-nav-holder ul li.active a, .wcmp-color-scheme-wild_watermelon .product-tab-nav-holder ul li.active a:hover, .wcmp-color-scheme-wild_watermelon .product-tab-nav-holder ul li.active a:focus {
  border-top-color: #fd5668; }
.wcmp-color-scheme-wild_watermelon .primary-color {
  color: #fd5668; }

.dashboard-top-content {
  background-color: #f7f8fa; }
  .dashboard-top-content h3 {
    margin: 0; }

.wcmp_vendor_transaction_details {
  color: #fff; }
  .wcmp_vendor_transaction_details .panel-body {
    background: #3f85b9 !important;
    color: inherit;
    border: 0 !important; }
  .wcmp_vendor_transaction_details .panel-footer {
    background: #306fa8 !important;
    border: 0 !important; }
    .wcmp_vendor_transaction_details .panel-footer a {
      color: inherit; }
  .wcmp_vendor_transaction_details .transaction-details div.total-balance-wrap {
    padding: 20px; }
  .wcmp_vendor_transaction_details .transaction-details h4 {
    display: inline-block;
    margin: 0;
    color: inherit; }
  .wcmp_vendor_transaction_details .transaction-details .transaction-list {
    padding: 0;
    margin: -20px 0 0;
    list-style: none;
    color: inherit; }
    .wcmp_vendor_transaction_details .transaction-details .transaction-list li {
      border-bottom: 1px solid rgba(255, 255, 255, 0.5); }
    .wcmp_vendor_transaction_details .transaction-details .transaction-list p {
      margin-bottom: 0;
      width: calc(100% - 70px);
      display: inline-block;
      padding-right: 10px; }
      .wcmp_vendor_transaction_details .transaction-details .transaction-list p .order-id {
        display: block;
        opacity: 0.65; }
        .wcmp_vendor_transaction_details .transaction-details .transaction-list p .order-id a {
          color:inherit; }
  .wcmp_vendor_transaction_details .wcmp_dashboard_widget_total_transaction {
    font-weight: 600;
    color: inherit;
    opacity: 0.65;
    margin-top: 0;
    line-height: 1;
    font-size: 41px; }

table.table.product_sold_last_week tbody {
  text-align: left; }
table.table.product_sold_last_week .wcmp_no-data {
  text-align: center; }
table.table.product_sold_last_week .product_sold_last_week_name_class img {
  margin-right: 12px;
  width: 26px;
  height: auto;
  max-height: 26px; }

#widget_product_sales_report.wcmp-widget-dt.table.dataTable tbody td,
#widget_vendor_pending_shipping.wcmp-widget-dt.table.dataTable tbody td {
  border-top: 1px solid #d3dbe2; }

.wcmp_vendor_product_sales_report.panel.panel-default.pannel-outer-heading .panel-body,
.wcmp_vendor_pending_shipping.panel.panel-default.pannel-outer-heading .panel-body {
  background: transparent; }

.wcmp_vendor_pending_shipping .table-bordered > thead > tr > th {
  white-space: nowrap; }

td:focus {
  outline: none; }

.panel.panel-default.wcmp_vendor_stats_reports {
  margin-top: 0; }

.staticstics-panel-wrap .panel-body h2 {
  margin: 20px 0; }
.staticstics-panel-wrap .panel-body > h2 {
  background: #333b3d;
  color: #fff;
  padding: 16px 20px;
  margin: -16px -16px 5px; }
.staticstics-panel-wrap .panel-body .short-stat-info-list {
  padding: 0;
  list-style: none;
  margin: 10px 0 0;
  border: 1px solid #d3dbe2; }
  .staticstics-panel-wrap .panel-body .short-stat-info-list:first-of-type {
    margin: 0; }
  .staticstics-panel-wrap .panel-body .short-stat-info-list li {
    padding: 8px 0;
    border-bottom: 1px solid #d3dbe2;
    overflow: hidden; }
    .staticstics-panel-wrap .panel-body .short-stat-info-list li > span {
      width: 28%;
      display: inline-block;
      font-size: 15px;
      vertical-align: middle; }
      .staticstics-panel-wrap .panel-body .short-stat-info-list li > span.stat-icon {
        width: 31%;
        text-align: right;
        font-size: 28px;
        padding-right: 37px;
        color: #333332; }
        @media screen and (max-width: 1280px) {
          .staticstics-panel-wrap .panel-body .short-stat-info-list li > span.stat-icon {
            width: 29%;
            font-size: 23px;
            padding-right: 26px; } }
      .staticstics-panel-wrap .panel-body .short-stat-info-list li > span.current-stat-report {
        padding: 5px 6px;
        margin: 0 9% 0 0; }
      .staticstics-panel-wrap .panel-body .short-stat-info-list li > span.prev-stat-report {
        color: #a6afb2; }
    .staticstics-panel-wrap .panel-body .short-stat-info-list li:last-of-type {
      border: none; }
.staticstics-panel-wrap .panel-body .stat-detail-info {
  line-height: 22px;
  vertical-align: middle;
  font-size: 15px;
  margin: 0 0 8px; }
  .staticstics-panel-wrap .panel-body .stat-detail-info i {
    color: #3f85b9;
    font-size: 22px;
    vertical-align: middle; }
.staticstics-panel-wrap .panel-body .compare-stat-info {
  padding: 20px 25px;
  border: solid 1px #d3dbe2;
  margin: 15px 0;
  position: relative; }
  .staticstics-panel-wrap .panel-body .compare-stat-info:after {
    left: 0%;
    top: -1px;
    position: absolute;
    content: '';
    width: 6px;
    background: #3f85b9;
    left: -1px;
    top: -1px;
    bottom: -1px; }
  .staticstics-panel-wrap .panel-body .compare-stat-info span {
    font-style: italic; }
  .staticstics-panel-wrap .panel-body .compare-stat-info select {
    margin-left: 10px;
    display: inline-block;
    vertical-align: middle; }
  @media screen and (max-width: 550px) {
    .staticstics-panel-wrap .panel-body .compare-stat-info {
      padding: 15px; }
      .staticstics-panel-wrap .panel-body .compare-stat-info select {
        display: block;
        margin: 8px 0 0; } }
.staticstics-panel-wrap .panel-body .wcmp-website-stat-list {
  padding: 0;
  list-style: none;
  margin: 0 0 -10px 0;
  overflow: hidden; }
  .staticstics-panel-wrap .panel-body .wcmp-website-stat-list li {
    float: left;
    color: #455053;
    margin: 0 2% 10px 0;
    width: 49%;
    line-height: 24px; }
    .staticstics-panel-wrap .panel-body .wcmp-website-stat-list li i {
      font-size: 25px;
      margin-right: 5px;
      vertical-align: middle; }
    .staticstics-panel-wrap .panel-body .wcmp-website-stat-list li span {
      display: inline;
      vertical-align: middle; }
    .staticstics-panel-wrap .panel-body .wcmp-website-stat-list li:nth-child(even) {
      margin-right: 0; }
    .staticstics-panel-wrap .panel-body .wcmp-website-stat-list li:nth-child(3) {
      clear: left; }
    @media screen and (max-width: 1280px) {
      .staticstics-panel-wrap .panel-body .wcmp-website-stat-list li {
        font-size: 13px; }
        .staticstics-panel-wrap .panel-body .wcmp-website-stat-list li mark {
          font-size: 12px; }
        .staticstics-panel-wrap .panel-body .wcmp-website-stat-list li i {
          font-size: 21px; } }
    @media screen and (max-width: 480px) {
      .staticstics-panel-wrap .panel-body .wcmp-website-stat-list li {
        width: 100%;
        margin: 0 0 10px; }
        .staticstics-panel-wrap .panel-body .wcmp-website-stat-list li:last-of-type {
          margin-bottom: 0; } }

.key-perfomence-indicator {
  width: 354px;
  max-width: 100%; }
  .key-perfomence-indicator + .col-md-8 {
    width: calc(100% - 354px); }
  @media screen and (max-width: 1280px) {
    .key-perfomence-indicator {
      width: 300px; }
      .key-perfomence-indicator + .col-md-8 {
        width: calc(100% - 300px); } }
  @media screen and (max-width: 991px) {
    .key-perfomence-indicator {
      width: 300px; }
      .key-perfomence-indicator + .col-md-8 {
        width: 100%; } }

.vendor_visitors_map .map-nav {
  box-shadow: 0 0 6px 1px rgba(0, 0, 0, 0.28);
  background: #fff;
  position: absolute;
  right: 10px;
  bottom: 10px;
  overflow: hidden;
  border-radius: 3px;
  line-height: 10px;
  text-align: center; }
.vendor_visitors_map .jqvmap-zoomin, .vendor_visitors_map .jqvmap-zoomout {
  color: #333332;
  background: #fff;
  position: relative;
  top: 0;
  left: 0;
  width: 25px;
  height: 25px;
  line-height: 18px;
  font-size: 16px; }
.vendor_visitors_map .jqvmap-zoomin:after {
  position: absolute;
  content: '';
  width: calc(100% - 8px);
  height: 1px;
  background: #e6e6e6;
  bottom: -1px;
  left: 0;
  right: 0;
  margin: auto;
  z-index: 1; }

#visitor_data_stats.table {
  margin-top: 20px; }
  #visitor_data_stats.table thead th {
    font-size: 11px; }
  #visitor_data_stats.table > tbody > tr > td {
    padding: 6px 7px;
    font-size: 12px; }
    #visitor_data_stats.table > tbody > tr > td.region {
      color: #fff; }
    #visitor_data_stats.table > tbody > tr > td.no_data {
      text-align: center; }
    #visitor_data_stats.table > tbody > tr > td:first-of-type {
      border: 0; }

.wcmp_vendor_products_cust_qna .customer-questions-panel article {
  overflow: hidden;
  border-bottom: solid 1px #d3dbe2; }
  .wcmp_vendor_products_cust_qna .customer-questions-panel article .media .media-body .qna-question {
    color: #4e4e4e;
    font-size: 14px;
    position: relative;
    padding-left: 20px;
    margin-bottom: 3px; }
    .wcmp_vendor_products_cust_qna .customer-questions-panel article .media .media-body .qna-question::before {
      content: 'Q.';
      color: #000;
      position: absolute;
      left: 0; }
    .wcmp_vendor_products_cust_qna .customer-questions-panel article .media .media-body .qna-question span {
      color: #000000; }
    .wcmp_vendor_products_cust_qna .customer-questions-panel article .media .media-body .qna-question + textarea {
      margin-top: 7px; }
  .wcmp_vendor_products_cust_qna .customer-questions-panel article .media .media-body .qna-date {
    font-size: 13px;
    display: block; }
    .wcmp_vendor_products_cust_qna .customer-questions-panel article .media .media-body .qna-date i {
      font-size: 16px; }
  .wcmp_vendor_products_cust_qna .customer-questions-panel article .media .media-body h4 {
    line-height: 18px; }
  .wcmp_vendor_products_cust_qna .customer-questions-panel article .media .media-body a {
    margin-top: 9px;
    font-size: 15px;
    line-height: 100%; }
    .wcmp_vendor_products_cust_qna .customer-questions-panel article .media .media-body a:hover {
      color: #000; }
  .wcmp_vendor_products_cust_qna .customer-questions-panel article:last-of-type {
    margin-bottom: 0; }
.wcmp_vendor_products_cust_qna .customer-questions-panel #customer_questions td {
  padding: 0; }

.vendor-products-qna-filters .form-group {
  max-width: 330px;
  vertical-align: top;
  min-width: 200px; }
.vendor-products-qna-filters .select2-container--default.select2-container--focus .select2-selection--multiple {
  border-color: #c5c5c5; }
.vendor-products-qna-filters .select2-container .select2-selection.select2-selection--multiple {
  min-height: 34px; }
.vendor-products-qna-filters #show_qna_by_products_btn {
  margin-left: 6px; }
.vendor-products-qna-filters .select2-container .select2-search--inline {
  margin-top: 7px; }
.vendor-products-qna-filters .select2-container .select2-selection.select2-selection--multiple .select2-selection__rendered .select2-selection__choice {
  margin-top: 5px; }
.vendor-products-qna-filters li + li.select2-search.select2-search--inline input.select2-search__field {
  width: 0.75em !important; }
@media screen and (max-width: 1070px) {
  .vendor-products-qna-filters {
    float: right;
    width: 100%;
    padding-bottom: 13px;
    border-bottom: 1px solid #ddd;
    margin-bottom: 12px; }
    .vendor-products-qna-filters .form-group {
      float: left;
      width: calc(100% - 100px);
      max-width: initial;
      margin-bottom: 0; } }

#vendor_products_qna_table span.unanswered.label-default {
  font-size: 12px;
  background-color: #f8dda7;
  color: #94660c; }
#vendor_products_qna_table span.answered.label-success {
  font-size: 12px;
  background-color: #c6e1c6;
  color: #5b841b; }

.wcmp_vendor_product_stats .wcmp_product_stats_wrap .p_stats_data {
  margin-top: 10px;
  padding-top: 10px;
  border-top: solid 2px #d4d7db; }
  .wcmp_vendor_product_stats .wcmp_product_stats_wrap .p_stats_data .list-group {
    margin: 0; }
    .wcmp_vendor_product_stats .wcmp_product_stats_wrap .p_stats_data .list-group .badge {
      background: #949c9e;
      border-radius: 0;
      float: none;
      position: absolute;
      right: 12px;
      top: 50%;
      -webkit-transform: translateY(-50%);
          -ms-transform: translateY(-50%);
              transform: translateY(-50%); }
.wcmp_vendor_product_stats .wcmp_product_stats_wrap #p_stats_piechart svg {
  overflow: visible !important; }
.wcmp_vendor_product_stats .wcmp_product_stats_wrap .list-group li {
  border: 1px solid #d3dbe2;
  margin-bottom: 8px;
  border-radius: 0;
  position: relative; }
  .wcmp_vendor_product_stats .wcmp_product_stats_wrap .list-group li .stat-left-border {
    position: absolute;
    top: -1px;
    left: -1px;
    width: 6px;
    bottom: -1px; }
  .wcmp_vendor_product_stats .wcmp_product_stats_wrap .list-group li > p {
    width: calc(100% - 25px); }
  .wcmp_vendor_product_stats .wcmp_product_stats_wrap .list-group li:last-child {
    margin-bottom: 0; }
.wcmp_vendor_product_stats .wcmp_product_stats_wrap .product-stat-chart {
  display: -webkit-box;
  display: flex;
  -webkit-box-align: end;
          align-items: flex-end;
  -webkit-box-pack: justify;
          justify-content: space-between;
  height: 160px;
  margin-top: 20px; }
  .wcmp_vendor_product_stats .wcmp_product_stats_wrap .product-stat-chart .product-stat-bar {
    background: #e0e6eb;
    width: 22%;
    text-align: center;
    height: 100%;
    position: relative; }
    .wcmp_vendor_product_stats .wcmp_product_stats_wrap .product-stat-chart .product-stat-bar .stat-percentage-holder {
      position: absolute;
      width: 100%;
      bottom: 0;
      left: 0; }
      .wcmp_vendor_product_stats .wcmp_product_stats_wrap .product-stat-chart .product-stat-bar .stat-percentage-holder:after {
        position: absolute;
        content: '';
        width: 100%;
        height: 1px;
        background: rgba(255, 255, 255, 0.17);
        left: 0;
        top: 0; }
      .wcmp_vendor_product_stats .wcmp_product_stats_wrap .product-stat-chart .product-stat-bar .stat-percentage-holder .stat-percentage-count {
        width: 100%;
        display: inline-block;
        color: #fff;
        position: absolute;
        left: 0;
        top: -22px;
        height: 22px;
        padding: 2px; }

#donutchart svg rect + text {
  font-size: 20px; }

.dash-widget-dt div.dataTables_wrapper div.dataTables_paginate {
  text-align: left; }

.dash-widget-dt div.dataTables_wrapper div.dataTables_paginate ul.pagination {
  margin: 15px 0 15px 20px; }

.wcmp-widget-dt.table.dataTable {
  margin: 0 !important; }

.wcmp-widget-dt.table.dataTable tbody td {
  border-top: none; }

table.dataTable tr th.sorting_asc {
  padding-right: 10px !important; }

.wcmp_customer_reviews .wcmp-comments {
  clear: both; }
  .wcmp_customer_reviews .wcmp-comments .media-list {
    margin: 0; }
    .wcmp_customer_reviews .wcmp-comments .media-list tr td {
      margin: 0;
      border-bottom: solid 1px #d3dbe2; }
      .wcmp_customer_reviews .wcmp-comments .media-list tr td .media-heading {
        font-size: 14px;
        color: #000000;
        margin-bottom: 8px; }
        .wcmp_customer_reviews .wcmp-comments .media-list tr td .media-heading small {
          margin-left: 10px; }
      .wcmp_customer_reviews .wcmp-comments .media-list tr td a {
        margin-top: 10px; }

.wcmp_vendor_pending_shipping table tbody tr td:last-of-type {
  vertical-align: middle; }
  .wcmp_vendor_pending_shipping table tbody tr td:last-of-type i {
    font-size: 21px;
    margin: 0; }

@media screen and (max-width: 600px) {
  table.responsive-table thead {
    display: none; }
  table.responsive-table tr {
    border-color: #eee; }
    table.responsive-table tr:nth-of-type(even) {
      background: #f9f9f9; }
    table.responsive-table tr:first-child td:first-child {
      border: 0 !important; }
  table.responsive-table td {
    display: block;
    padding: .7rem !important;
    text-align: left !important;
    border-width: 1px 0 0 !important; }
    table.responsive-table td > span {
      display: table-cell;
      padding-left: 10px; }
    table.responsive-table td:before {
      content: attr(data-th);
      font-weight: bold;
      width: 100px;
      vertical-align: top;
      display: table-cell;
      vertical-align: middle; }
  table.responsive-table caption {
    background-image: none; }

  .blank-responsive-table thead {
    display: none; } }
.dt-wrapper {
  overflow: auto; }
  .dt-wrapper table:not(.wcmp-widget-dt) {
    min-width: 850px;
    width: 100% !important; }

.wcmp_shop_settings_form .panel.panel-default:first-of-type, .wcmp_policy_form .panel.panel-default:first-of-type, .wcmp_billing_form .panel.panel-default:first-of-type, .all-products-wrapper .panel.panel-default:first-of-type, .coupons .panel.panel-default:first-of-type, .vendor-report .panel.panel-default:first-of-type, .vendor-orders .panel.panel-default:first-of-type, .vendor-withdrawal .panel.panel-default:first-of-type, .transaction-details .panel.panel-default:first-of-type, .add-staff .panel.panel-default:first-of-type, .vendor-tools .panel.panel-default:first-of-type, .vendor-knowledgebase .panel.panel-default:first-of-type, .wcmp_profile_form .panel.panel-default:first-of-type, .wcmp_shipping_form .panel.panel-default:first-of-type {
  margin-top: 0; }

.wcmp_policy_form .panel-body .form-group:last-of-type {
  margin-bottom: 0; }
  .wcmp_policy_form .panel-body .form-group:last-of-type .form-group {
    margin-bottom: 0; }

form[name="wcmp_vendor_dashboard_orders"] .form-group, #vendor_transactions_date_filter .form-group {
  margin-right: 8px; }

@media screen and (max-width: 1145px) {
  form[name="wcmp_vendor_dashboard_completed_stat_export"] {
    /* float: left; */
    width: 100%;
    margin-top: 12px; } }
@media screen and (max-width: 767px) {
  form[name="wcmp_vendor_dashboard_orders"] {
    float: none;
    margin: 0 auto;
    display: table;
    /* text-align: center;  */
  }

  form[name="wcmp_vendor_dashboard_orders"] .form-group,
  form[name="wcmp_vendor_dashboard_orders"] button,
  .datatable-date-filder .form-group,
  .datatable-date-filder button {
    display: inline-block;
    vertical-align: top;
    margin-bottom: 5px; } }
@media screen and (max-width: 480px) {
  form[name="wcmp_vendor_dashboard_orders"] button.btn, .datatable-date-filder button.btn {
    height: 30px;
    padding: 3px 8px; } }
.checkbox-holder {
  position: relative;
  display: inline-block;
  cursor: pointer;
  vertical-align: middle; }
  .checkbox-holder .wcmp-font {
    font-size: 20px;
    vertical-align: middle;
    color: #c5c5c5;
    position: absolute;
    left: 0;
    top: 0; }
  .checkbox-holder input[type="checkbox"] {
    width: 22px;
    height: 22px;
    opacity: 0;
    z-index: 1;
    position: relative;
    margin: 0 !important;
    vertical-align: middle !important;
    cursor: pointer; }
    .checkbox-holder input[type="checkbox"]:checked {
      background: #fff; }
      .checkbox-holder input[type="checkbox"]:checked + .ico-uncheckbox-icon {
        background: #fff; }
        .checkbox-holder input[type="checkbox"]:checked + .ico-uncheckbox-icon:before {
          content: '\e90b'; }

input[type=radio], input[type=checkbox] {
  border: 2px solid #cecdcd;
  background: #fff;
  color: #c5c5c5;
  clear: none;
  cursor: pointer;
  display: inline-block;
  line-height: 0;
  max-height: 20px;
  min-height: 20px;
  margin: 0;
  outline: 0;
  padding: 0 !important;
  text-align: center;
  vertical-align: middle;
  width: 20px;
  min-width: 20px;
  -webkit-appearance: none;
  -webkit-transition: .05s border-color ease-in-out;
  transition: .05s border-color ease-in-out;
  border-radius: 3px; }
  input[type=radio]:focus, input[type=checkbox]:focus {
    border-color: #cecdcd;
    box-shadow: none; }

input[type=radio]:checked:before, input[type=checkbox]:checked:before {
  float: left;
  display: inline-block;
  vertical-align: middle;
  width: 20px;
  height: 20px;
  font: 400 20px/1 'wcmp' !important;
  speak: none;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale; }

input[type=checkbox]:checked:before {
  content: '\e90b';
  margin: -2px 0 0 -2px; }

input[type=radio] {
  border-radius: 50%;
  line-height: 10px;
  left: 0;
  top: -1px; }

input[type=radio]:checked:before {
  content: "";
  border-radius: 50%;
  font-size: 24px;
  width: 12px;
  height: 12px;
  margin: 2px;
  line-height: 16px; }

input[type=radio]:checked {
  border-color: #66afe9;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px rgba(102, 175, 233, 0.6); }

input[type=radio]:focus, input[type=checkbox]:focus {
  outline: none; }

.form-horizontal .checkbox, .form-horizontal .radio {
  min-height: 22px; }

table th input[type=checkbox] {
  border: 2px solid #afadad; }

table th .checkbox-holder .wcmp-font {
  color: #afafaf;
  background: #fff; }

.pro_ele_hide + .wcmp-font, .pro_head_hide + .wcmp-font, .pro_block_hide + .wcmp-font, .non_stock_ele_hide + .wcmp-font, .non_virtual_ele_hide + .wcmp-font, .downloadable_ele_hide + .wcmp-font, .vendor_hidden + .wcmp-font {
  display: none !important; }

.slug-inp {
  display: inline-block;
  width: 150px;
  max-width: 100%; }

.upload_button.wcmp_black_btn, .remove_button.wcmp_black_btn {
  display: block !important; }

.wcmp_media_block .dc-wp-fields-uploader {
  display: block; }
  .wcmp_media_block .dc-wp-fields-uploader img {
    border-radius: 0; }
.wcmp_media_block .button-group .btn {
  width: 100%;
  display: block;
  border-radius: 0; }

.panel.panel-default.vendor-cover-panel {
  margin-bottom: 55px; }

.vendor-cover-wrap {
  position: relative; }
  .vendor-cover-wrap #vendor-cover-img {
    min-height: 200px; }
  .vendor-cover-wrap img {
    height: auto;
    width: 100%; }
  .vendor-cover-wrap .vendor-profile-pic-wraper {
    width: 100px;
    position: absolute;
    bottom: -37px;
    left: 20px;
    overflow: hidden;
    padding-bottom: 37px; }
    .vendor-cover-wrap .vendor-profile-pic-wraper .profile-pic-btn {
      position: absolute;
      bottom: 0;
      right: 0;
      width: 100%;
      background: #3f85b9;
      padding: 5px;
      color: #fff;
      -webkit-transition: all 0.3s;
      transition: all 0.3s;
      text-align: center; }
      .vendor-cover-wrap .vendor-profile-pic-wraper .profile-pic-btn button {
        background: transparent;
        border: none;
        padding: 0;
        height: 27px; }
        .vendor-cover-wrap .vendor-profile-pic-wraper .profile-pic-btn button span {
          font-size: 17px; }
      .vendor-cover-wrap .vendor-profile-pic-wraper .profile-pic-btn:hover {
        background: #202627; }
  .vendor-cover-wrap .cover-pic-button {
    position: absolute;
    bottom: 30px;
    right: 125px; }
    .vendor-cover-wrap .cover-pic-button button {
      border: none;
      background: #3f85b9;
      padding: 9px 15px;
      color: #fff;
      -webkit-transition: all 0.3s;
      transition: all 0.3s; }
      .vendor-cover-wrap .cover-pic-button button:hover {
        background: #202627; }
    @media screen and (max-width: 1024px) {
      .vendor-cover-wrap .cover-pic-button {
        right: 20px;
        bottom: 20px;
        font-size: 13px; }
        .vendor-cover-wrap .cover-pic-button button {
          padding: 9px 10px; } }
  @media screen and (max-width: 640px) {
    .vendor-cover-wrap img {
      min-height: auto; }
    .vendor-cover-wrap .vendor-profile-pic-wraper {
      width: 120px;
      height: auto;
      overflow: visible;
      margin: auto;
      left: 0;
      right: 0;
      bottom: -72px;
      padding-bottom: 0; }
      .vendor-cover-wrap .vendor-profile-pic-wraper img {
        border-width: 5px; }
      .vendor-cover-wrap .vendor-profile-pic-wraper .profile-pic-btn {
        bottom: 5px;
        right: 5px;
        width: auto;
        line-height: 10px;
        padding: 2px 5px;
        height: 25px; }
        .vendor-cover-wrap .vendor-profile-pic-wraper .profile-pic-btn button {
          font-size: 0; }
          .vendor-cover-wrap .vendor-profile-pic-wraper .profile-pic-btn button .wcmp-font {
            font-size: 15px;
            line-break: 21px; }
    .vendor-cover-wrap .cover-pic-button {
      right: 0;
      bottom: 0;
      font-size: 0; }
      .vendor-cover-wrap .cover-pic-button button {
        padding: 5px;
        height: 25px; }
        .vendor-cover-wrap .cover-pic-button button .wcmp-font {
          font-size: 15px; } }

.wcmp_media_block .facebook {
  color: #4867aa; }
.wcmp_media_block .twitter {
  color: #1da1f2; }
.wcmp_media_block .linkedin {
  color: #007bb6; }
.wcmp_media_block .google-plus {
  color: #dd4c40; }
.wcmp_media_block .youtube {
  color: #ff0000; }
.wcmp_media_block .instagram {
  color: #8536ec; }

.wcmp_template_list li {
  position: relative;
  margin: 0 4% 20px 0;
  width: 48%;
  float: left;
  vertical-align: top; }
  .wcmp_template_list li:nth-child(2n+2) {
    margin-right: 0; }
  .wcmp_template_list li label {
    cursor: pointer;
    margin: 0; }
    .wcmp_template_list li label i.dashicons {
      position: absolute;
      background: #151715;
      color: #fff;
      padding: 8px;
      top: 50%;
      width: 35px;
      left: 50%;
      height: 35px;
      z-index: 1;
      -webkit-transform: translateX(-50%) translateY(-50%);
          -ms-transform: translateX(-50%) translateY(-50%);
              transform: translateX(-50%) translateY(-50%);
      opacity: 0; }
  .wcmp_template_list li input[type="radio"] {
    visibility: hidden;
    display: none; }
  .wcmp_template_list li .template-overlay {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background: rgba(0, 0, 0, 0.3);
    opacity: 0;
    -webkit-transition: all 0.3s;
    transition: all 0.3s; }
  .wcmp_template_list li input[type="radio"]:checked + i.dashicons {
    background: #fff;
    opacity: 1; }
  .wcmp_template_list li input[type="radio"]:checked + i.dashicons + .template-overlay {
    opacity: 1;
    background: rgba(0, 0, 0, 0.5); }
  @media screen and (max-width: 640px) {
    .wcmp_template_list li {
      width: 400px;
      max-width: 100%;
      margin: 0 auto 15px !important;
      float: none; } }
  .wcmp_template_list li:hover .template-overlay {
    opacity: 1; }
  .wcmp_template_list li:hover i.dashicons {
    opacity: 1; }

/*....................... shipping page .....................*/
.shipping_table {
  margin-bottom: 25px; }
  .shipping_table tr > td {
    padding: 20px; }
  .shipping_table tr td h2, .shipping_table tr td label, .shipping_table tr td input {
    margin: 0; }
  .shipping_table h2 {
    font-size: 20px; }

.shipping_table tr td,
.shipping_table tr th {
  padding: 20px; }

.shipping_table tr td label {
  color: #4d4d4d;
  font-size: 15px;
  font-weight: 700;
  padding: 0; }

.shipping_table tr td input[type="text"],
.shipping_table tr td input[type="number"] {
  border: 1px solid #dedede;
  box-shadow: none;
  color: #7e7e7e;
  font-size: 14px;
  height: 28px;
  line-height: 43px;
  margin: 0 4% 0;
  padding: 3px 5px;
  width: 92%; }

.hints {
  padding: 21px 10% 15px;
  overflow: hidden; }

.hints {
  background: #f6f6f6 none repeat scroll 0 0;
  border: 1px solid #e5e6e5;
  border-radius: 3px;
  color: #3a3a39;
  font-size: 11px;
  padding: 2% 5%;
  position: relative;
  margin-top: 10px; }
  .hints:after {
    content: '';
    border: none;
    background: none;
    border-bottom: 7px solid  #e5e6e5;
    border-left: 7px solid transparent;
    border-right: 7px solid transparent;
    height: 0;
    left: 5px;
    padding: 0;
    position: absolute;
    top: -8px;
    width: 0; }

.shipping_table tr td input[type="submit"] {
  -moz-border-bottom-colors: none;
  -moz-border-left-colors: none;
  -moz-border-right-colors: none;
  -moz-border-top-colors: none;
  background: rgba(0, 0, 0, 0) -moz-linear-gradient(center top, #f74b33 0%, #e1442e 50%, #cf3f2b 100%) repeat scroll 0 0;
  border-color: #ff8877 -moz-use-text-color #9f291a;
  -webkit-border-image: none;
       -o-border-image: none;
          border-image: none;
  border-radius: 4px;
  border-style: solid none;
  border-width: 2px 0;
  color: #fff;
  cursor: pointer;
  float: right;
  font-size: 15px;
  font-weight: bold;
  margin: 3px 4%;
  padding: 9px 15px; }

.vendor_non_configuration_msg {
  margin: 28px;
  color: #fc482f; }

.wcmp_billing_form .payment-gateway h4 {
  margin-top: 50px; }
.wcmp_billing_form .payment-gateway .form-group:last-of-type {
  margin-bottom: 0; }

table.shipping_table td {
  border: 1px solid #d1d7df !important; }

.frontend_product_manager_product_types {
  background: #fff;
  padding: 20px; }
  .frontend_product_manager_product_types .form-group {
    display: inline-block;
    vertical-align: top;
    margin: 0; }
    .frontend_product_manager_product_types .form-group #product_type {
      vertical-align: middle;
      min-width: 120px; }
    .frontend_product_manager_product_types .form-group.is_virtual_wrapper {
      margin-right: 15px;
      margin-left: 15px; }
    .frontend_product_manager_product_types .form-group label {
      vertical-align: middle;
      display: inline-block;
      margin: 7px 0 0;
      padding: 0; }
    .frontend_product_manager_product_types .form-group.product_type_wrapper {
      margin: 0; }
      .frontend_product_manager_product_types .form-group.product_type_wrapper label {
        margin-top: 6px; }
    @media screen and (max-width: 1023px) {
      .frontend_product_manager_product_types .form-group.product_type_wrapper {
        display: block;
        margin-bottom: 10px; }
      .frontend_product_manager_product_types .form-group.is_virtual_wrapper {
        margin-left: 0; } 
      .form-horizontal #usage_limit_coupon_data .control-label {
          max-width: 50%;
      }
      .all-products-wrapper .product_search {
        padding: 0;
        text-align:left;
     }
        }
  .frontend_product_manager_product_types [class*="col-sm-"] {
    width: auto !important;
    display: inline-block;
    vertical-align: middle; }
  .frontend_product_manager_product_types .wcmp-no-product-type-notice {
    float: right;
    margin-top: 9px; }
  @media screen and (max-width: 480px) {
    .frontend_product_manager_product_types {
      padding: 10px; }
      .frontend_product_manager_product_types #product_type {
        font-size: 12px; }
      .frontend_product_manager_product_types .product_type_wrapper .product_type.pro_title + .col-md-6 {
        padding: 0 0 0 8px; } }

#mceu_26 {
  border-right-width: 1px !important; }

@media (min-width: 768px) {
  .multi_input_block .form-group label + .col-sm-9 {
    width: 75%; }

  .vendor-orders form[name="wcmp_vendor_dashboard_orders"], .datatable-date-filder {
    float: right; } }
.frontend_product_manager_product_types .product_type.pro_title {
  padding: 0; }

#product_manager_form .frontend_product_manager_product_types .form-group label {
  margin: 10px 0 0; }

.default_attributes_holder .dft_sel_wrap select {
  margin: 0 6% 10px 0; }
  .default_attributes_holder .dft_sel_wrap select:nth-child(even) {
    margin-right: 0; }
  .default_attributes_holder .dft_sel_wrap select:nth-last-of-type(2), .default_attributes_holder .dft_sel_wrap select:last-of-type {
    margin-bottom: 0; }
.default_attributes_holder select.regular-select {
  width: 47%;
  display: inline-block; }

.multi_input_block label.vari_select_lbl + select {
  width: 69%;
  margin: 0 0 0 3%;
  display: inline-block; }

.add-product-backend {
  padding: 20px;
  border-top: 1px solid #d3dbe2;
  background: #fff;
  font-size: 16px; }
  .add-product-backend p {
    margin: 0; }
    .add-product-backend p i {
      font-size: 20px;
      vertical-align: middle;
      margin: 0 0 4px 9px;
      display: inline-block; }

.woocommerce-exporter-wrapper .wc-progress-steps li.active, .woocommerce-importer-wrapper .wc-progress-steps li.active, .woocommerce-progress-form-wrapper .wc-progress-steps li.active {
  border-color: #3f85b9 !important;
  color: #3f85b9 !important; }

.woocommerce-exporter-wrapper .wc-progress-steps li.active::before, .woocommerce-importer-wrapper .wc-progress-steps li.active::before, .woocommerce-progress-form-wrapper .wc-progress-steps li.active::before {
  border-color: #3f85b9 !important; }

body .woocommerce-exporter-wrapper .button, body .woocommerce-importer-wrapper .button, body .woocommerce-progress-form-wrapper .button {
  box-shadow: none !important;
  text-shadow: none !important;
  line-height: 20px !important;
  font-size: 14px !important;
  padding: 3px 8px !important;
  border: 1px solid !important; }

.woocommerce-exporter-wrapper .button:active, .woocommerce-exporter-wrapper .button:focus, .woocommerce-exporter-wrapper .button:hover, .woocommerce-importer-wrapper .button:active, .woocommerce-importer-wrapper .button:focus, .woocommerce-importer-wrapper .button:hover, .woocommerce-progress-form-wrapper .button:active, .woocommerce-progress-form-wrapper .button:focus, .woocommerce-progress-form-wrapper .button:hover {
  background: #3f85b9 !important;
  box-shadow: none !important;
  color: #fff !important; }

.woocommerce-exporter-wrapper .wc-progress-steps li.done, .woocommerce-importer-wrapper .wc-progress-steps li.done, .woocommerce-progress-form-wrapper .wc-progress-steps li.done {
  border-color: #fff !important;
  color: #fff !important; }

.woocommerce-exporter-wrapper .wc-progress-steps li.done::before, .woocommerce-importer-wrapper .wc-progress-steps li.done::before, .woocommerce-progress-form-wrapper .wc-progress-steps li.done::before {
  border-color: #fff !important;
  background: #fff !important; }

body .woocommerce.wrap {
  margin: 0; }

.product-import .woocommerce.wrap, .product-export .woocommerce.wrap {
  display: block;
  margin: 30px auto 0;
  max-width: 100%; }
  .product-import .woocommerce.wrap h1, .product-export .woocommerce.wrap h1 {
    display: none; }
  .product-import .woocommerce.wrap table tr, .product-export .woocommerce.wrap table tr {
    background: transparent; }
    .product-import .woocommerce.wrap table tr th, .product-import .woocommerce.wrap table tr td, .product-export .woocommerce.wrap table tr th, .product-export .woocommerce.wrap table tr td {
      border: none; }

body .woocommerce-progress-form-wrapper {
  margin-top: 10px; }

.woocommerce-importer-options input + br {
  display: none; }

.product-export .woocommerce.wrap, .product-export .woocommerce-exporter-wrapper {
  width: 100%;
  max-width: 100%;
  margin-top: 0;
  margin-bottom: 0; }

.woocommerce-exporter h2 {
  margin: 0 0 1px !important;
  color: #252525 !important;
  font-size: 17px !important;
  line-height: 22px !important; }
  .woocommerce-exporter h2 + p {
    margin: 0 0 15px !important;
    font-size: 13px !important; }
.woocommerce-exporter .woocommerce-exporter-options td {
  padding: 0 0 15px 0; }
  .woocommerce-exporter .woocommerce-exporter-options td .select2-container {
    width: 300px !important;
    max-width: 100% !important; }

body .wc_bookings_calendar_form .tablenav {
  border: none;
  box-shadow: none; }

body .wc_bookings_calendar_form .tablenav {
  margin: 0 0 25px;
  display: inline-block;
  width: 100%;
  border-bottom: solid 1px #d3dbe2;
  padding-bottom: 20px; }
  body .wc_bookings_calendar_form .tablenav .date_selector {
    margin-left: 5px;
    display: block;
    float: left; }
    body .wc_bookings_calendar_form .tablenav .date_selector a {
      display: block;
      text-indent: -9999px;
      position: relative;
      height: 1em;
      width: 1em;
      font-size: 1.3em;
      padding: .6em; }
      body .wc_bookings_calendar_form .tablenav .date_selector a.prev, body .wc_bookings_calendar_form .tablenav .date_selector a.next {
        padding: 0;
        margin: 6px 6px 0;
        width: 29px;
        height: 29px;
        position: relative; }
      body .wc_bookings_calendar_form .tablenav .date_selector a:before {
        font: normal normal normal 25px/1 LineAwesome;
        speak: none;
        font-weight: 400;
        font-variant: normal;
        text-transform: none;
        line-height: 1;
        -webkit-font-smoothing: antialiased;
        margin: 0;
        text-indent: 0;
        position: absolute;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        text-align: center; }
      body .wc_bookings_calendar_form .tablenav .date_selector a.prev {
        float: left; }
        body .wc_bookings_calendar_form .tablenav .date_selector a.prev:before {
          content: "←";
          font-size: 30px; }
      body .wc_bookings_calendar_form .tablenav .date_selector a.next {
        float: right; }
        body .wc_bookings_calendar_form .tablenav .date_selector a.next:before {
          content: "→";
          font-size: 30px; }
    body .wc_bookings_calendar_form .tablenav .date_selector div {
      padding: 5px 0;
      float: left; }
      body .wc_bookings_calendar_form .tablenav .date_selector div:first-of-type select {
        margin-right: 5px; }
    body .wc_bookings_calendar_form .tablenav .date_selector select {
      vertical-align: middle;
      width: 6em; }
  body .wc_bookings_calendar_form .tablenav .views {
    float: right;
    padding: 0;
    border-left: 1px solid #ddd; }
    body .wc_bookings_calendar_form .tablenav .views a {
      padding: 11px 20px;
      display: block;
      text-decoration: none; }
      body .wc_bookings_calendar_form .tablenav .views a i {
        font-size: 19px;
        margin-right: 7px; }
  body .wc_bookings_calendar_form .tablenav .filters {
    float: left;
    line-height: 30px;
    padding: 5px 15px 5px 5px;
    border-right: 1px solid #ddd; }
body .wc_bookings_calendar_form .calendar_days {
  overflow: auto;
  position: relative;
  height: 1440px;
  overflow: hidden;
  overflow-x: auto;
  border: 1px solid #ddd;
  background-image: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAA8CAYAAACn8dD6AAAAIElEQVQYGWO4e/fuf4afP3/+Z2IAgsFCfP36lWHQuQoAvaoOvF/jxHkAAAAASUVORK5CYII=);
  background-repeat: repeat;
  background-position: 0 0; }
  body .wc_bookings_calendar_form .calendar_days .hours {
    list-style: none;
    padding: 0;
    position: absolute;
    top: 0;
    left: 0;
    margin: -0.5em 0 0 0; }
  body .wc_bookings_calendar_form .calendar_days .hours li {
    height: 60px;
    vertical-align: top;
    padding: 0;
    margin: 0; }
  body .wc_bookings_calendar_form .calendar_days .hours li label {
    float: left;
    background: #f9f9f9;
    padding: 0 8px; }
  body .wc_bookings_calendar_form .calendar_days .bookings {
    margin: 0 0 0 100px;
    padding: 0;
    height: 100%;
    white-space: nowrap;
    position: relative; }
  body .wc_bookings_calendar_form .calendar_days .bookings li {
    position: absolute;
    width: 98px;
    background: #000;
    border-radius: 2px;
    margin: 0;
    overflow: hidden;
    color: #fff; }
  body .wc_bookings_calendar_form .calendar_days .bookings li a {
    display: block;
    padding: 2px 4px;
    height: 100%;
    width: 100%;
    position: relative;
    color: #fff;
    text-decoration: none; }
body .wc_bookings_calendar_form .wc_bookings_calendar .calendar-diff-month {
  background: #efefef; }
body .wc_bookings_calendar_form .wc_bookings_calendar td {
  color: #bbb;
  text-align: right;
  padding: 8px 8px 0 0;
  font-size: 20px;
  border-right: 1px solid #ddd;
  border-bottom: 1px solid #ddd;
  height: 120px; }
  body .wc_bookings_calendar_form .wc_bookings_calendar td .bookings {
    overflow: auto;
    height: 100px;
    width: 100%;
    text-align: left;
    font-size: 15px; }
  body .wc_bookings_calendar_form .wc_bookings_calendar td .bookings ul {
    padding: 0;
    margin: 0; }
  body .wc_bookings_calendar_form .wc_bookings_calendar td .bookings ul li {
    padding: 0;
    margin: 0 0 4px 0;
    list-style: none; }
  body .wc_bookings_calendar_form .wc_bookings_calendar td .bookings ul li a {
    border-left: 4px solid #eee;
    padding: 3px 3px 3px 8px;
    display: block; }
  body .wc_bookings_calendar_form .wc_bookings_calendar td .bookings ul li a ul {
    padding: 0;
    margin: 0; }
  body .wc_bookings_calendar_form .wc_bookings_calendar td .bookings ul li a ul li {
    list-style: none;
    font-size: .75em;
    padding: 0;
    margin: 0;
    border: 0; }
  body .wc_bookings_calendar_form .wc_bookings_calendar td .bookings ul li a:hover {
    border-left-color: #ccc;
    background: #fafafa; }

div.dataTables_wrapper div.dataTables_length select.wcmp_filter_bookings {
  width: auto; }

.wc_bookings_calendar tr th {
  padding-bottom: 10px; }

.all-booking .wcmp_tab.ui-tabs {
  padding: 0;
  border: none; }
  .all-booking .wcmp_tab.ui-tabs label {
    font-weight: normal; }
  .all-booking .wcmp_tab.ui-tabs .dataTables_filter {
    text-align: right; }
    .all-booking .wcmp_tab.ui-tabs .dataTables_filter .form-control {
      margin-left: 0.5em; }
  .all-booking .wcmp_tab.ui-tabs .wcmp_booking_tbl {
    margin-top: 5px; }
    .all-booking .wcmp_tab.ui-tabs .wcmp_booking_tbl tbody strong, .all-booking .wcmp_tab.ui-tabs .wcmp_booking_tbl tbody .wcmp_table_action {
      color: #333b3d; }
      .all-booking .wcmp_tab.ui-tabs .wcmp_booking_tbl tbody strong:hover, .all-booking .wcmp_tab.ui-tabs .wcmp_booking_tbl tbody .wcmp_table_action:hover {
        color: #3f85b9; }

.booking-details .booking-customer-details tbody {
  border: 1px solid #ddd; }
.booking-details .booking-customer-details th {
  border-bottom-color: #ddd;
  background: initial;
  border-right: 1px solid #ddd; }
  .booking-details .booking-customer-details th th {
    background: initial; }

#mceu_64-head #mceu_64-t0, #mceu_64-head #mceu_64-t2 {
  display: none !important; }
#mceu_64-head #mceu_64-t1 {
  display: block !important; }

#mceu_64-body #mceu_65, #mceu_64-body #mceu_74 {
  display: none !important; }
#mceu_64-body #mceu_72 {
  display: none !important; }

.mce-container.mce-panel.mce-foot button {
  color: #fff; }

.mce-container iframe {
  min-height: 100px !important; }

@media screen and (max-width: 1100px) {
  /* .product_search {
    width: 100%;
    padding: 15px 0;
    border-top: 1px solid #ddd;
    border-bottom: 1px solid #ddd; } */
    /* .product_search .pro_search_key {
      width: calc(100% - 74px); } */

  #product_bulk_actions {
    /* width: calc(100% - 63px); */
    margin: 8px 0; }

  body .product-filter-actions .alignleft.actions button:not(:last-of-type) {
    margin-right: 0; }

  .product_filters li {
    float: none;
    margin-bottom: 15px; }

  #product_cat {
    max-width: calc(100% - 270px);
    min-width: 147px; } }
body .select2-container--default .select2-search--inline .select2-search__field[placeholder]:not([placeholder=""]) {
  width: 100% !important; }

.select2-container--default .select2-search--inline {
  width: 100%; }

.select2-container--default li + .select2-search--inline {
  width: auto; }

@media screen and (max-width: 480px) {
  body .woocommerce table.form-table .select2-container {
    min-width: auto !important; }

  body .woocommerce-exporter .woocommerce-exporter-options td .select2-container {
    width: auto !important; }

  .products.content-padding #product_cat {
    max-width: calc(100% - 203px);
    min-width: 120px;
    margin: 0;
    display: inline-block;
    font-size: 12px;
    padding-right: 15px !important;
    background-position: right 3px top 50%; }
  .products.content-padding #product_types {
    font-size: 12px;
    width: 139px;
    padding-left: 3px;
    padding-right: 15px !important;
    background-position: right 3px top 50%; }

  /* .product_search .pro_search_key {
    width: calc(100% - 69px); } */
     }
#wc_bookings_field_duration {
  display: inline-block;
  vertical-align: middle; }

.wc_bookings_field_start_date legend .label {
  padding: 0;
  margin-top: 26px;
  display: inline-block; }

.product_filters {
  line-height: 0.7;
  margin-top: 13px; }

.product-filter-actions .alignleft.actions button {
  border-radius: 4px; }

.product-filter-actions .alignleft.actions button:not(:last-of-type) {
  margin-right: 10px; }

.product-list-filter-wrap .form-group {
  margin-bottom: 7px; }

#product_table tbody .select_product {
  text-align: center;
  vertical-align: middle; }

#product_table th.actions, #product_table td.actions {
  min-width: 110px !important; }

#product_table td.actions .col-actions {
  white-space: nowrap; }

.product-title-wrap {
  overflow: hidden; }

.select-product-cat-wrapper .cat-intro img {
  margin: 30px 0; }
.select-product-cat-wrapper .cat-intro .serach-product-cat-wrapper {
  margin-bottom: 40px; }
  .select-product-cat-wrapper .cat-intro .serach-product-cat-wrapper h2 {
    color: #333b3d; }
  .select-product-cat-wrapper .cat-intro .serach-product-cat-wrapper form {
    margin: 15px 0 45px;
    position: relative; }
    .select-product-cat-wrapper .cat-intro .serach-product-cat-wrapper form .form-control {
      max-width: 100%;
      width: 395px; }
    @media screen and (max-width: 892px) {
      .select-product-cat-wrapper .cat-intro .serach-product-cat-wrapper form .form-control {
        width: 100%; }
      .select-product-cat-wrapper .cat-intro .serach-product-cat-wrapper form > .btn {
        margin-top: 10px; } }
    .select-product-cat-wrapper .cat-intro .serach-product-cat-wrapper form:after {
      content: '...';
      position: absolute;
      bottom: -39px;
      font-size: 41px;
      left: 0;
      right: 0;
      margin: auto;
      color: rgba(110, 114, 115, 0.7);
      pointer-events: none; }
.select-product-cat-wrapper .cat-intro .search-result-holder .search-result-clm {
  border-bottom: 1px solid #d3dbe2;
  padding: 20px;
  overflow: hidden; }
  .select-product-cat-wrapper .cat-intro .search-result-holder .search-result-clm img {
    margin: 0 25px 0 0;
    float: left;
    border: 1px solid #d3dbe2;
    padding: 10px;
    max-height: 98px;
    width: auto;
    max-width: 130px; }
  .select-product-cat-wrapper .cat-intro .search-result-holder .search-result-clm .result-content {
    width: calc(100% - 312px);
    display: inline-block;
    vertical-align: middle; }
  .select-product-cat-wrapper .cat-intro .search-result-holder .search-result-clm a.item-sell {
    margin-left: 30px; }
  @media screen and (max-width: 1000px) {
    .select-product-cat-wrapper .cat-intro .search-result-holder .search-result-clm .result-content {
      width: 100%;
      margin: 15px 0; }
    .select-product-cat-wrapper .cat-intro .search-result-holder .search-result-clm a.item-sell {
      margin-left: 0; } }
.select-product-cat-wrapper .select-cat-step-wrapper .wcmp-categories-level-panel {
  background: #fff url("../../images/icon-bg.png") repeat top;
  border: 1px solid #d3dbe2;
  padding: 20px;
  overflow: hidden; }
.select-product-cat-wrapper .select-cat-step-wrapper .cat-list-holder {
  position: relative;
  height: 367px;
  overflow: hidden;
  background: transparent !important; }
.select-product-cat-wrapper .select-cat-step-wrapper .cat-column-scroller {
  position: absolute;
  width: 50px;
  background: #e1e6ec;
  color: #3f85b9;
  text-align: center;
  cursor: pointer;
  z-index: 3;
  font-size: 28px;
  top: 0;
  bottom: 0; }
  .select-product-cat-wrapper .select-cat-step-wrapper .cat-column-scroller i {
    position: absolute;
    top: 50%;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%);
    left: 0;
    right: 0;
    margin: auto; }
  .select-product-cat-wrapper .select-cat-step-wrapper .cat-column-scroller.cat-left-scroller {
    left: 0; }
  .select-product-cat-wrapper .select-cat-step-wrapper .cat-column-scroller.cat-right-scroller {
    right: 0; }
.select-product-cat-wrapper .select-cat-step-wrapper .has-scroller.wcmp-categories-level-panel {
  padding-left: 60px;
  padding-right: 60px;
  position: relative; }
.select-product-cat-wrapper .select-cat-step-wrapper .cat-column-wrapper {
  overflow: hidden;
  position: relative;
  height: 100%;
  -webkit-transition: all 0.3s;
  transition: all 0.3s; }
  .select-product-cat-wrapper .select-cat-step-wrapper .cat-column-wrapper .cat-column:nth-last-of-type(3) {
    border-right: 1px solid #d3dbe2; }
  .select-product-cat-wrapper .select-cat-step-wrapper .cat-column-wrapper .cat-column:not(:first-child) {
    margin-left: -1px; }
.select-product-cat-wrapper .select-cat-step-wrapper .select-category-graphic {
  float: left;
  width: 66.67%;
  text-align: center;
  position: absolute;
  top: 50%;
  -webkit-transform: translateY(-50%);
      -ms-transform: translateY(-50%);
          transform: translateY(-50%);
  right: 0; }
  .select-product-cat-wrapper .select-cat-step-wrapper .select-category-graphic img {
    margin: 0 0 15px; }
  .select-product-cat-wrapper .select-cat-step-wrapper .select-category-graphic h1 {
    font-weight: 300;
    color: #4e5a5d; }
  .select-product-cat-wrapper .select-cat-step-wrapper .select-category-graphic:after {
    position: absolute;
    content: '';
    width: 471px;
    height: 261px;
    box-shadow: 1px 1px 176px white;
    left: 0;
    right: 0;
    margin: auto;
    top: -27px;
    bottom: 0;
    z-index: -1;
    background: rgba(255, 255, 255, 0.4);
    border-radius: 240px 240px 25px 25px; }
  @media screen and (max-width: 1099px) {
    .select-product-cat-wrapper .select-cat-step-wrapper .select-category-graphic {
      width: 40%; }
      .select-product-cat-wrapper .select-cat-step-wrapper .select-category-graphic h1 {
        font-size: 23px;
        line-height: 28px; } }
.select-product-cat-wrapper .select-cat-step-wrapper .cat-column {
  width: 33.33%;
  float: left;
  border: 1px solid #d3dbe2;
  height: 100%;
  overflow: auto;
  background: #fff; }
  .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li {
    position: relative; }
    .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li:after {
      content: '';
      position: absolute;
      background: #d3dbe2;
      width: calc(100% - 60px);
      height: 1px;
      margin: auto;
      left: 0;
      right: 0;
      bottom: 0; }
    .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li:last-of-type:after {
      display: none; }
    .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li.has-children a:before {
      content: "\e92f";
      font-family: 'wcmp' !important;
      font-style: normal;
      font-weight: normal;
      font-variant: normal;
      text-transform: none;
      line-height: 1;
      -webkit-font-smoothing: antialiased;
      -moz-osx-font-smoothing: grayscale;
      position: absolute;
      right: 30px;
      top: 50%;
      -webkit-transform: translateY(-50%);
          -ms-transform: translateY(-50%);
              transform: translateY(-50%);
      z-index: 1; }
    .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li a {
      color: #4e5a5d;
      padding: 14px 50px 14px 30px;
      display: block;
      position: relative; }
      .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li a span {
        position: relative;
        z-index: 1; }
      .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li a:after {
        position: absolute;
        content: '';
        width: 100%;
        height: calc(100% + 1px);
        left: 0;
        top: -1px;
        background: #d3dbe2;
        opacity: 0; }
      .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li a:hover {
        color: #3f85b9; }
        .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li a:hover:after {
          opacity: 1; }
        .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li a:hover:before {
          color: #3f85b9; }
    .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li.active a {
      color: #3f85b9; }
      .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li.active a:after {
        opacity: 1; }
      .select-product-cat-wrapper .select-cat-step-wrapper .cat-column li.active a:before {
        color: #3f85b9; }
.select-product-cat-wrapper .select-cat-step-wrapper .select-cat-button-holder {
  width: 33.33%;
  float: left;
  position: relative;
  height: 100%; }
  .select-product-cat-wrapper .select-cat-step-wrapper .select-cat-button-holder .final-cat-button {
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    margin: auto;
    width: 193px;
    max-width: 100%;
    height: 168px;
    text-align: center; }
    .select-product-cat-wrapper .select-cat-step-wrapper .select-cat-button-holder .final-cat-button button {
      position: absolute;
      top: 50%;
      left: 0;
      right: 0;
      margin: auto;
      -webkit-transform: translateY(-50%);
          -ms-transform: translateY(-50%);
              transform: translateY(-50%);
      width: 80%; }
.select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .form-text, .select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .form-input {
  display: inline-block;
  vertical-align: middle; }
.select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .form-text {
  font-weight: 400;
  color: #333b3d;
  margin-right: 15px; }
.select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .form-input {
  width: 524px;
  max-width: 100%;
  height: 39px;
  border: 1px solid #c5c5c5;
  padding: 3px 3px 3px 55px;
  position: relative;
  border-radius: 4px; }
  .select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .form-input:before {
    position: absolute;
    content: '\e93e';
    font-family: 'wcmp' !important;
    font-style: normal;
    font-weight: normal;
    font-variant: normal;
    text-transform: none;
    line-height: 1;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    font-size: 22px;
    position: absolute;
    left: 18px;
    top: 50%;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%); }
  .select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .form-input input {
    background: transparent;
    border: 0;
    width: 100%;
    height: 100%;
    padding: 2px; }
    .select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .form-input input:focus {
      outline: none; }
.select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .list-group {
  z-index: 2;
  position: relative;
  left: -56px;
  top: 15px;
  display: inline-block;
  max-height: 326px;
  overflow: auto;
  width: 700px;
  overflow: auto; }
  .select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .list-group .list-group-item {
    border-radius: 0 !important;
    padding: 20px 28px;
    width: 700px;
    overflow: auto;
    cursor: pointer; }
    .select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .list-group .list-group-item p {
      color: #212121;
      margin-bottom: 3px; }
    .select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .list-group .list-group-item:hover {
      background: #edf1f4;
      color: #3f85b9; }
      .select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .list-group .list-group-item:hover p {
        color: #3f85b9; }
  @media screen and (max-width: 1200px) {
    .select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .list-group {
      width: calc(100% + 61px); }
      .select-product-cat-wrapper .select-cat-step-wrapper .product-search-wrapper .list-group .list-group-item {
        max-width: 100%;
        padding: 13px; } }
.select-product-cat-wrapper .select-cat-step-wrapper .cat-step2 .form-group input {
  width: 350px;
  max-width: 100%; }
.select-product-cat-wrapper .select-cat-step-wrapper .cat-step2 .form-group label {
  margin-right: 15px; }
.select-product-cat-wrapper .select-cat-step-wrapper .breadcrumb {
  margin: 0;
  display: inline-block;
  vertical-align: middle; }
  .select-product-cat-wrapper .select-cat-step-wrapper .breadcrumb > li + li::before {
    content: ">";
    color: #626c6f;
    padding: 0 8px; }
.select-product-cat-wrapper .select-cat-step-wrapper .reset-btn {
  display: inline-block;
  vertical-align: middle;
  margin-left: 20px; }
  .select-product-cat-wrapper .select-cat-step-wrapper .reset-btn i {
    vertical-align: middle;
    margin-right: 5px; }
  .select-product-cat-wrapper .select-cat-step-wrapper .reset-btn span {
    text-decoration: underline;
    vertical-align: middle; }
.select-product-cat-wrapper .select-cat-step-wrapper .panel-heading h1 .primary-color span {
  opacity: 0.7; }

.cat-step3 .product-title-wrap.product-add-mode .editing-content {
  display: inline-block; }
.cat-step3 .product-title-wrap.product-add-mode .grey-blockquote .editable-content-button, .cat-step3 .product-title-wrap.product-add-mode .grey-blockquote .editabble-button {
  display: none; }

.product-visibility-toggle-inner {
  padding: 15px; }

.dropdown-panel {
  background: #fff;
  width: 238px;
  box-shadow: 0 10px 10px rgba(0, 0, 0, 0.11);
  border: 1px solid #d3dbe2;
  position: absolute;
  right: 16px;
  z-index: 1; }

.dropdown-panel .form-group {
  margin-left: 0;
  margin-right: 0; }

.has-multiple-cat {
  float: left;
  width: calc(100% - 430px); }

.has-multiple-cat + .pull-right {
  margin: 19px 0 0;
  padding-bottom: 10px; }

.cat-breadcrumb {
  display: inline-block;
  vertical-align: middle; }

#multi_cat_hierarchy_visiblity {
  margin-top: 36px; }

.editable-content-button, .editabble-button {
  background: transparent;
  padding: 0;
  color: #7eaed1;
  box-shadow: none;
  border: none;
  margin: 0 0 0 10px; }
  .editable-content-button i, .editabble-button i, .editable-content-button span, .editabble-button span {
    text-decoration: underline; }

.breadcrumb li:before {
  display: none; }

.breadcrumb > li:after {
  content: '';
  width: 5px;
  margin: 0 13px 0 17px;
  display: inline-block;
  height: 9px;
  background: url(../../images/breadcrumb-icon.png) no-repeat left center;
  vertical-align: middle; }

.breadcrumb > li:last-child:after {
  display: none; }

[data-target="#multi_cat_hierarchy_visiblity"][aria-expanded="true"]
.wcmp-font.ico-downarrow-2-icon::before,
[data-target="#product_visiblity"][aria-expanded="true"]
.wcmp-font.ico-downarrow-2-icon::before {
  content: '\e938'; }

.wcmp-product-cat-level .mCSB_container {
  margin-right: 0 !important;
  width: 100%;
  min-height: 100%; }

.cat-step3 .panel-heading {
  padding: 0; }
.cat-step3 .cat-breadcrumb-wrap {
  margin-bottom: 15px;
  overflow: hidden;
  padding: 10px;
  background: #fff;
  border: 1px solid #d3dbe2; }
  .cat-step3 .cat-breadcrumb-wrap .wcmp-breadcrumb {
    margin: 0;
    padding: 4px 5px 4px 40px;
    background: url(../../images/cat-icon.png) no-repeat left top 13px;
    margin-top: -10px; }
    .cat-step3 .cat-breadcrumb-wrap .wcmp-breadcrumb li {
      margin-top: 12px; }
  .cat-step3 .cat-breadcrumb-wrap .multiple-cat-hierarchy {
    margin: 0;
    padding: 4px 0 4px 25px;
    background: url(../../images/multiple-cat-icon.png) no-repeat left center; }
    .cat-step3 .cat-breadcrumb-wrap .multiple-cat-hierarchy .multi-cat-choose-dflt-btn {
      font-weight: normal;
      color: #797b7b; }
      .cat-step3 .cat-breadcrumb-wrap .multiple-cat-hierarchy .multi-cat-choose-dflt-btn i {
        text-decoration: none !important;
        color: #212121;
        margin-left: 5px; }
.cat-step3 .product-title-wrap {
  padding: 20px;
  margin-bottom: 20px;
  border: 1px solid #d4dbe3;
  border-left-width: 4px;
  background: #fff;
  display: inline-block;
  width: 100%; }
  .cat-step3 .product-title-wrap .product-title-inner {
    position: relative;
    width: calc(100% - 350px);
    max-width: 100%; }
    .cat-step3 .product-title-wrap .product-title-inner p:last-child {
      margin-bottom: 0; }
    .cat-step3 .product-title-wrap .product-title-inner p label {
      min-width: 92px;
      margin: 0; }
  .cat-step3 .product-title-wrap .editing-content {
    vertical-align: middle;
    display: none;
    width: 405px;
    max-width: 100%; }
  .cat-step3 .product-title-wrap #product_visiblity {
    right: 16px;
    z-index: 9; }
  .cat-step3 .product-title-wrap .gtin-detal {
    margin-bottom: 0; }
  .cat-step3 .product-title-wrap .cat-visiblity {
    text-align: right; }
.cat-step3 .pro-view {
  word-break: break-word; }
.cat-step3 [data-target="#product_visiblity"] {
  border: 1px solid #bdbdbd;
  padding: 0px 4px;
  font-size: 12px;
  color: #212121; }
  .cat-step3 [data-target="#product_visiblity"] .wcmp-font {
    text-decoration: none;
    font-size: 12px; }

.dropdown-panel {
  background: #fff;
  width: 238px;
  box-shadow: 0 10px 10px rgba(0, 0, 0, 0.11);
  border: 1px solid #d3dbe2;
  position: absolute;
  z-index: 1; }
  .dropdown-panel .wcmp-vendor_stock_alert {
    padding: 15px; }
  .dropdown-panel .form-group {
    margin-bottom: 0; }
    .dropdown-panel .form-group input {
      margin-right: 6px; }
    .dropdown-panel .form-group span {
      display: inline-block;
      vertical-align: middle;
      width: calc(100% - 31px); }
    .dropdown-panel .form-group label {
      width: 100%; }
  .dropdown-panel hr {
    margin: 9px 0 19px; }
  .dropdown-panel .btn-sm {
    margin-right: 5px; }
  .dropdown-panel .list-group li {
    border-top: solid 1px #ddd; }
    .dropdown-panel .list-group li:first-child {
      border: 0; }
    .dropdown-panel .list-group li a {
      padding: 8px;
      display: block; }
    .dropdown-panel .list-group li.active {
      background: #f3f3f3; }

.change-status {
  margin: 0 0 0 30px; }
  .change-status .order-status-text {
    background: #fff;
    border: 1px solid #d3dbe2;
    height: 25px;
    padding: 2px 11px 2px 29px; }
    .change-status .order-status-text i {
      display: inline-block;
      width: 30px;
      height: 30px;
      vertical-align: top;
      position: absolute;
      background: #f36f5a;
      z-index: 1;
      margin: -6px 0 0 -36px;
      border-radius: 50%;
      line-height: 30px;
      text-align: center;
      color: #fff; }
  .change-status .order-status-edit-button {
    margin: 3px 0 0 10px;
    cursor: pointer;
    color: #3f85b9;
    float: left; }
  .change-status .dropdown-panel {
    margin-top: 8px; }

.fc-content-skeleton tr {
  background: transparent; }

.fc-toolbar .fc-state-active, .fc-toolbar .ui-state-active {
  z-index: 1; }

.product-import.wcmp_displaybox2m, .wcmp_displaybox2 {
  margin-bottom: 15px;
  text-align: left;
  overflow: hidden;
  border: solid 1px #a1aeb7;
  border-left: solid 7px #a1aeb7;
  padding: 2px; }
  .product-import.wcmp_displaybox2m h4, .wcmp_displaybox2 h4 {
    color: #555;
    display: inline-block;
    margin: 0;
    vertical-align: middle;
    padding: 10px;
    width: calc(100% - 155px); }
  .product-import.wcmp_displaybox2m h3, .wcmp_displaybox2 h3 {
    margin-bottom: 0;
    color: #3f85b9;
    font-size: 16px;
    display: inline-block;
    vertical-align: middle;
    font-weight: bold;
    margin: 0;
    line-height: 21px;
    padding: 10px 15px;
    background: #e4e9ed;
    width: 150px;
    text-align: right;
    position: relative; }
    .product-import.wcmp_displaybox2m h3:after, .wcmp_displaybox2 h3:after {
      content: '';
      position: absolute;
      top: 0;
      left: -3px;
      width: 1px;
      height: 100%;
      background: #d2dbe2; }
    .product-import.wcmp_displaybox2m h3 sup, .wcmp_displaybox2 h3 sup {
      font-size: inherit;
      margin-right: 3px;
      top: 0; }
  .product-import.wcmp_displaybox2m .woocommerce-Price-currencySymbol, .wcmp_displaybox2 .woocommerce-Price-currencySymbol {
    font-size: 20px;
    margin-right: 3px;
    vertical-align: top; }

.wcmp_displaybox3 {
  border: 1px solid #dfdfdf;
  box-shadow: 0 3px 0 1px rgba(0, 0, 0, 0.05);
  margin: 25px 0 0;
  padding: 10px 2%;
  width: 98%;
  background: #fff;
  color: #3f3f3f;
  font-size: 15px;
  font-weight: 400;
  line-height: 30px;
  width: 100%;
  text-align: center; }
  .wcmp_displaybox3 h3 {
    color: #3f85b9;
    font-size: 27px;
    line-height: 30px;
    margin: 0; }

.stat-detail-row .wcmp_displaybox3 {
  float: left;
  width: 30%;
  margin-right: 5%; }
  .stat-detail-row .wcmp_displaybox3:nth-child(3n+3) {
    margin-right: 0; }
  @media screen and (max-width: 768px) {
    .stat-detail-row .wcmp_displaybox3 {
      width: 45%;
      margin-right: 10%; }
      .stat-detail-row .wcmp_displaybox3:nth-child(3n+3) {
        margin-right: 10%; }
      .stat-detail-row .wcmp_displaybox3:nth-child(2n+2) {
        margin-right: 0; } }
  @media screen and (max-width: 640px) {
    .stat-detail-row .wcmp_displaybox3 {
      width: 100%;
      margin-right: 0% !important; } }

.panel-info {
  background: #39677f;
  border-left: 5px solid #39677f;
  color: #fff;
  margin: 0; }

@media screen and (max-width: 1100px) {
  form.stat-date-range .panel-heading h3 {
    display: block;
    padding-bottom: 5px; }
    form.stat-date-range .panel-heading h3 + .form-group {
      margin-left: 0; } }
form.stat-date-range .panel-heading .form-group {
  margin-left: 10px; }
@media screen and (max-width: 950px) {
  form.stat-date-range .panel-heading .form-group {
    display: inline-block;
    vertical-align: top;
    margin: 0; }
  form.stat-date-range .panel-heading .form-group:last-of-type {
    display: block;
    margin-top: 5px; }
  form.stat-date-range .panel-heading .date-inp-wrap input {
    width: 150px; } }
@media screen and (max-width: 480px) {
  form.stat-date-range .panel-heading .date-inp-wrap input {
    width: 100%; }
  form.stat-date-range .panel-heading .form-group {
    display: block;
    margin-bottom: 5px; }
  form.stat-date-range .panel-heading .to-text {
    display: block;
    text-align: center; } }

.multi_input_block {
  border: 1px solid #dfdfdf;
  border-radius: 10px;
  border-radius: 10px;
  -moz-border-radius: 10px;
  -webkit-border-radius: 10px;
  padding: 10px;
  margin-bottom: 10px; }

.multi_input_block_manupulate {
  float: right;
  margin: 11px 0 0 !important;
  cursor: pointer;
  width: 15px;
  height: 15px;
  background: #ccc;
  text-align: center;
  line-height: 15px;
  border-radius: 50%; }
  .multi_input_block_manupulate.button-secondary {
    margin-left: 5px !important; }
  .multi_input_block_manupulate:hover {
    background: #3f85b9;
    color: #fff; }

.pro_ele_hide, .pro_head_hide, .pro_block_hide, .non_stock_ele_hide, .non_virtual_ele_hide, .downloadable_ele_hide, .vendor_hidden {
  display: none !important; }

p.description {
  font-size: 13px;
  font-style: italic;
  font-weight: normal;
  margin: 4px 0 0; }

.img_tip {
  display: inline-block;
  margin-left: 5px;
  position: relative; }
  .img_tip:after {
    content: '\e92a';
    font-family: 'wcmp' !important;
    font-size: 16px;
    color: #000;
    cursor: help; }

.tool_tip {
  position: relative;
  float: right;
  top: -17px;
  right: -15px; }
  .tool_tip:after {
    content: '\e92a';
    font-family: 'wcmp' !important;
    font-size: 16px;
    color: #000;
    position: absolute;
    top: 50%;
    right: -7px;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%);
    cursor: help; }
  @media screen and (max-width: 991px) {
    .tool_tip {
      right: -7px; }
      .tool_tip:after {
        font-size: 12px; } }

label .tool_tip {
  top: 0;
  right: 0; }
  label .tool_tip:after {
    top: 0;
    right: 0;
    -webkit-transform: none;
        -ms-transform: none;
            transform: none; }

.qtip-content {
  color: #fff;
  line-height: 15px; }

.checkbox-group-addon div {
  margin-bottom: 8px; }
  .checkbox-group-addon div label {
    margin: 0 0 0 4px; }

.wcmp_table_holder, .staff-detail-wrap, .sub_vendor_error {
  clear: both; }

.staff-detail-wrap {
  border: 0;
  padding: 0; }

.sub_vendor_error {
  color: #a94442; }

.sub_vendor_success {
  color: #3c763d !important; }

.vendor-msg {
  display: none; }

#wcmp-vendor-orders_wrapper .row > .col-sm-6, #vendor_transactions_wrapper .row > .col-sm-6 {
  width: auto; }

.wcmp-order-totals-items .wc-used-coupons .wc_coupon_list .code {
    display: inline-block;
    position: relative;
    padding: 0 .5em;
    background-color: #fff;
    border: 1px solid #aaa;
    box-shadow: 0 1px 0 #dfdfdf;
    border-radius: 4px;
    margin-right: 5px;
    margin-top: 5px;
}
#wcmp_order_data_refunds .wcmp-order-actions { padding-top: 20px; }
select[name="wcmp-vendor-orders_length"] {
  margin-left: 10px;
  margin-right: 10px; }

#customer_questions .qna-date {
  display: block; }

.btn.btn-danger {
  background: #b41e1e !important;
  border-color: #b41e1e !important; }
  .btn.btn-danger:hover {
    background: #202627 !important;
    border-color: #202627 !important; }

.customer-detail-inner {
  border: 1px solid #d3dbe2;
  padding: 15px;
  margin: 10px 5px; }
  .customer-detail-inner h3 {
    margin-bottom: 10px; }
  .customer-detail-inner p {
    margin-bottom: 5px; }

.icon-header {
  margin-bottom: 25px; }
  .icon-header > span {
    float: left;
    margin: 0 8px 0 -5px; }
    .icon-header > span i {
      font-size: 50px; }
  .icon-header h2 {
    font-size: 22px;
    margin: 0 0 4px;
    padding-top: 1px; }
  .icon-header h3 {
    color: inherit; }
    .icon-header h3 .processing {
      color: #5b841b; }
    .icon-header h3 .on-hold {
      color: #94660c; }
    .icon-header h3 .completed {
      color: #2e4453; }
    .icon-header h3 .cancelled, .icon-header h3 .refunded, .icon-header h3 .pending {
      color: #777; }
    .icon-header h3 .failed {
      color: #761919; }

.single-order-detail-table table .order-item-img {
  width: 80px;
  margin-right: 15px;
  text-align: center;
  background: #d2dbe2; }
  .single-order-detail-table table .order-item-img.icon-item {
    padding: 15px 10px;
    font-size: 30px; }
.single-order-detail-table table .shipping-row .refund-btn {
  vertical-align: bottom; }
.single-order-detail-table table .refund-row td {
  vertical-align: bottom !important; }
.single-order-detail-table table .order-thumb, .single-order-detail-table table .item_cost, .single-order-detail-table table .quantity, .single-order-detail-table table .line_cost, .single-order-detail-table table .wcmp-item-commission {
  width: 100px; }
.single-order-detail-table table input {
  max-width: 80px; }
.single-order-detail-table table table {
  margin-top: 2px; }
  .single-order-detail-table table table td, .single-order-detail-table table table th {
    padding: 1px; }
  .single-order-detail-table table table th {
    padding-right: 15px;
    padding-left: 0; }
.single-order-detail-table .table > tbody + tbody {
  border-top: 1px solid #ddd; }
.single-order-detail-table .wcmp-order-totals td, .single-order-detail-table .wc-order-totals td {
  padding-bottom: 10px !important;
/*  padding-right: 20px !important; */
}
.single-order-detail-table .form-control {
  height: 28px; }

/* .order_download_permissions .select2-container {
  width: calc(100% - 143px) !important; } */

.change-status .wc-pending i {
  background: #f58020; }
  .change-status .wc-pending i:before {
    content: '\e957';
    margin: 0 0 0 3px; }
.change-status .wc-processing i {
  background: #fec40d; }
  .change-status .wc-processing i:before {
    content: '\e958'; }
.change-status .wc-on-hold i {
  background: #ce9416; }
  .change-status .wc-on-hold i:before {
    content: '\e954'; }
.change-status .wc-completed i {
  background: #37a972; }
  .change-status .wc-completed i:before {
    content: '\e950'; }
.change-status .wc-cancelled i {
  background: #c84040; }
  .change-status .wc-cancelled i:before {
    content: '\e94f'; }
.change-status .wc-refunded i {
  background: #349bd5; }
  .change-status .wc-refunded i:before {
    content: '\e959'; }
.change-status .wc-failed i {
  background: #f36f59; }
  .change-status .wc-failed i:before {
    content: '\e954'; }
.change-status .change-status.loaderOverlay:after {
  left: -6px;
  top: -3px;
  right: -6px;
  bottom: -3px; }

.download-product-permission input.form-control {
  width: 400px;
  max-width: 100%; }

.order-action li i {
  margin-right: 5px;
  font-size: 20px;
  vertical-align: middle; }
.order-action .list-group-item {
  border: 0;
  border-top: 1px solid #d3dbe2; }
  .order-action .list-group-item:first-child {
    border: 0; }
  .order-action .list-group-item a {
    display: table; }
    .order-action .list-group-item a i {
      display: table-cell;
      vertical-align: top;
      padding-right: 10px; }
.order-action form {
  margin-bottom: 5px; }
  .order-action form select.form-control {
    width: 250px;
    max-width: 100%;
    margin-right: 5px; }

.order-notes .order-note {
  padding: 15px 12px;
  background: #dde2e8;
  margin-bottom: 13px;
  position: relative;
  color: #dde2e8; }
  .order-notes .order-note p {
    color: #626c6f; }
    .order-notes .order-note p:last-child {
      margin: 0; }
  .order-notes .order-note span {
    color: #212121; }
  .order-notes .order-note:after {
    content: '';
    position: absolute;
    left: 25px;
    bottom: -9px;
    width: 0;
    height: 0;
    border-width: 11px 10px 0 10px;
    border-style: solid;
    border-color: inherit;
    border-left-color: transparent;
    border-right-color: transparent; }
  .order-notes .order-note.customer-note {
    background: #a7cedc;
    color: #a7cedc; }
  .order-notes .order-note.system-note {
    background: #d7cad2;
    color: #d7cad2; }

.tools-item {
  overflow: hidden; }
  .tools-item label {
    margin-bottom: 0; }
  .tools-item p {
    margin-top: 7px; }
  .tools-item .wcmp_vendor_clear_transients {
    margin-top: 5px; }
  .tools-item .col-md-3 {
    text-align: right; }
  @media screen and (max-width: 768px) {
    .tools-item {
      text-align: center; } }
  .tools-item .col-md-3 {
    text-align: center;
    margin-top: 10px; }

.top-order-note td {
  padding: 5px; }
.top-order-note th {
  padding-right: 10px; }

.order-detail-top-panel > .panel-heading {
  overflow: visible !important; }

.order-address-info {
  border-top: 0 !important; }
.order-address-info hr { 
    margin: 9px 0 15px;
}
  @media screen and (min-width: 992px) {
    .order-address-info > .row {
      display: -webkit-box;
      display: flex; } }
  .order-address-info .col-md-4 .border {
    padding: 20px 25px;
    height: 100%; }
    .order-address-info .col-md-4 .border h3 {
      margin-bottom: 8px; }
    .order-address-info .col-md-4 .border p {
      margin-bottom: 3px; }
    .order-address-info .col-md-4 .border .customer-detail {
      display: table; }
      .order-address-info .col-md-4 .border .customer-detail .icon {
        display: table-cell;
        padding-right: 10px;
        vertical-align: top;
        max-width: 62px; }
        .order-address-info .col-md-4 .border .customer-detail .icon i {
          font-size: 25px;
          margin-right: 10px;
          background: #d3dce1;
          padding: 16px 14px;
          vertical-align: top;
          display: inline-block; }
      .order-address-info .col-md-4 .border .customer-detail p {
        margin-bottom: 1px; }

.withdrawal-transaction-wrapper{ overflow: auto; }
@media screen and (max-width: 1030px) {
  .transaction-details #vendor_transactions_date_filter {
    width: 100%;
    text-align: center;
    margin-bottom: 15px; }
  .transaction-details #vendor_transactions_wrapper > .row {
    text-align: center; }
    .transaction-details #vendor_transactions_wrapper > .row .col-sm-6 {
      width: 100%; } }

.pending-vendor-dashboard .navbar-default.sidebar:after, .rejected-vendor-dashboard .navbar-default.sidebar:after {
  content: '';
  width: 100%;
  height: 100%;
  top: 50px;
  position: absolute;
  left: 0;
  background: rgba(0, 0, 0, 0.65);
  clear: none; }

.wcmp-rejected-vendor-notice, .wcmp-pending-vendor-notice {
  padding: 20px; }

.note-clm-wrap {
  padding-left: 30px;
  position: relative; }

.note-clm-wrap:after {
  content: '';
  width: 1px;
  height: 100%;
  background: #ccc;
  position: absolute;
  top: 0;
  left: 0; }

.note-clm-wrap .note-clm:last-of-type {
  margin-bottom: 0; }

.note-clm {
  display: block;
  padding: 14px 17px;
  max-width: 60%;
  margin: 0 5% 20px 0;
  border: 1px solid #ccc;
  position: relative;
  border-radius: 6px; }

.note-clm:before {
  width: 13px;
  height: 13px;
  border: 2px solid #fff;
  border-radius: 100px;
  margin: 16px 0 0 -4px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.2), inset 0 1px 1px rgba(0, 0, 0, 0.1);
  background: #fd5869;
  content: "";
  position: absolute;
  top: 0;
  left: -33px;
  z-index: 1;
  box-sizing: border-box; }

.note-clm:after {
  width: 9px;
  height: 9px;
  border-width: 0 0 1px 1px;
  border-style: solid;
  border-color: #ccc;
  background: #fff;
  -webkit-transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  transform: rotate(45deg);
  content: "";
  position: absolute;
  top: 18px;
  left: -6px; }

.note-description {
  margin: 0 0 21px; }

.note-clm p.note-meta {
  margin: 0;
  display: inline-block;
  color: #969696; }

.note-clm p.note-meta.note_owner {
  margin-left: 10px; }

.wcmp-regi-form-row {
  margin-bottom: 20px;
  overflow: hidden; }

.wcmp-regi-form-row label {
  width: 25%;
  float: left;
  font-weight: normal; }

.wcmp-regi-form-row input[type="text"],
.wcmp-regi-form-row input[type="url"],
.wcmp-regi-form-row input[type="password"],
.wcmp-regi-form-row input[type="email"],
.wcmp-regi-form-row input[type="file"],
.wcmp-regi-form-row textarea {
  padding: 3px 5px;
  box-shadow: none;
  line-height: 20px;
  border: 1px solid #c5c5c5;
  height: 34px;
  font-size: 14px;
  border-radius: 4px;
  float: left;
  width: 50%; }

.wcmp-regi-form-row textarea {
  height: 100px; }

.wcmp_regi_form_box .reg_header2 {
  border-top: 1px solid #ddd;
  padding-top: 30px;
  margin-top: 32px;
  font-size: 21px;
  padding-bottom: 10px; }

.wcmp-regi-radio-inp-holder {
  float: left;
  width: 50%; }

.reapply_vendor_application_form .wcmp-regi-12 input[type=file] {
  padding: 5px 5px; }

@media screen and (max-width: 767px) {
  .reapply_vendor_application_form .wcmp-regi-12 input[type=text], .reapply_vendor_application_form .wcmp-regi-12 input[type=url], .reapply_vendor_application_form .wcmp-regi-12 input[type=file] {
    width: 100%; }

  .note-clm {
    max-width: 100%;
    margin-right: 0; } }
.wcmp_profile_form #vendor-profile-img {
  width: 130px;
  padding: 3px;
  border: solid 1px #ccc;
  margin-bottom: 8px; }

.wcmp-do-change-pass {
  margin-top: 6px; }

.zone-component {
  position: relative; }
  .zone-component .shipping-zone-list i {
    margin-right: 8px; }
  .zone-component .shipping-zone-list + .form-group {
    margin-top: 15px; }

.wcmp-shipping-zone-methods .method_disabled {
  text-decoration: line-through; }

.zone-method-table .col-actions {
  white-space: nowrap; }

#usage_restriction_coupon_data .form-group-row {
  border-bottom: solid 1px #d3dbe2;
  margin-bottom: 20px;
  padding-bottom: 20px; }
#usage_restriction_coupon_data .coupon-products-wrap .select2.select2-container {
  margin-bottom: 10px; }

.vendor-announcements #tabs-1.ui-tabs.ui-widget.ui-widget-content.ui-corner-all {
  background: rgba(0, 0, 0, 0) none repeat scroll 0 0;
  border: 0 solid #dddddd;
  color: #333333;
  padding: 0 !important;
  border-radius: 0px !important; }

.vendor-announcements #tabs-1 .ui-widget-header {
  background: transparent none repeat scroll 0 0 !important;
  border: 0 solid #dcdcdc !important;
  border-bottom-width: 1px !important;
  border-radius: 0 !important;
  color: #ffffff;
  font-weight: bold;
  padding: 40px 0 !important;
  text-align: center;
  width: 100%; }

.vendor-announcements .ui-tabs .ui-tabs-panel {
  padding: 0 !important; }

.vendor-announcements #tabs-1.ui-tabs .ui-tabs-nav li {
  border-bottom-width: 0;
  border-radius: 0px;
  display: inline-block !important;
  float: none !important;
  list-style: outside none none;
  margin: 0 8px 0 0;
  padding: 0;
  position: relative;
  top: 0;
  white-space: nowrap;
  border: 1px solid #b1b1b1 !important; }

.vendor-announcements .ui-state-default,
.vendor-announcements .ui-widget-content .ui-state-default,
.vendor-announcements .ui-widget-header .ui-state-default {
  background: #f4f4f4 none repeat scroll 0 0;
  background-image: none !important;
  border: 0 solid #fbd850 !important;
  border-radius: 0;
  font-size: 15px;
  font-weight: bold; }

.vendor-announcements .ui-state-default:hover,
.vendor-announcements .ui-widget-content .ui-state-default:hover,
.vendor-announcements .ui-widget-header .ui-state-default:hover {
  background: #fff; }

.vendor-announcements .ui-state-default a,
.vendor-announcements .ui-state-default a:link,
.vendor-announcements .ui-state-default a:visited {
  color: #a0a0a0 !important; }

.vendor-announcements .ui-state-active,
.vendor-announcements .ui-widget-content .ui-state-active,
.vendor-announcements .ui-widget-header .ui-state-active {
  background: #ffffff none repeat scroll 0 0;
  border: 0 solid #fbd850 !important;
  border-radius: 0;
  font-size: 15px;
  font-weight: bold; }

.vendor-announcements .ui-state-active a,
.vendor-announcements .ui-state-active a:link,
.vendor-announcements .ui-state-active a:visited {
  color: #3e3e3e !important; }

.vendor-announcements .ui-state-hover,
.vendor-announcements .ui-widget-content .ui-state-hover,
.vendor-announcements .ui-widget-header .ui-state-hover,
.vendor-announcements .ui-state-focus,
.vendor-announcements .ui-widget-content .ui-state-focus,
.vendor-announcements .ui-widget-header .ui-state-focus {
  border: 0 solid #fbcb09;
  background: none;
  font-weight: bold;
  color: #222222; }

.vendor-announcements .ui-state-default,
.vendor-announcements .ui-widget-content .ui-state-default,
.vendor-announcements .ui-widget-header .ui-state-default {
  background: #f4f4f4 !important;
  background-image: none !important;
  border: 1px solid #e9e9e9 !important;
  border-top: none !important;
  color: #868686 !important;
  font-weight: 700 !important; }

.vendor-announcements .ui-state-active,
.vendor-announcements .ui-widget-content .ui-state-active,
.vendor-announcements .ui-widget-header .ui-state-active {
  background: #ffffff !important;
  border: 1px solid #e9e9e9 !important;
  border-top: none !important;
  color: #222222 !important;
  font-weight: 700; }

.vendor-announcements .ui-accordion .ui-accordion-header .ui-accordion-header-icon {
  display: none; }

.vendor-announcements .ui-accordion .ui-accordion-icons {
  padding: 0px !important; }

.vendor-announcements .ui-accordion .ui-accordion-header {
  margin-top: 0px !important;
  clear: both;
  overflow: hidden;
  width: 100%; }

.vendor-announcements .msg_date_box {
  width: 15%;
  min-height: 75px;
  border-right: 1px solid #dcdcdc;
  font-size: 13px;
  font-weight: 700;
  float: left;
  text-align: center;
  padding-top: 12px; }

.vendor-announcements .msg_date_box span {
  font-size: 23px; }

.vendor-announcements .msg_title_box {
  min-height: 75px;
  font-size: 15px;
  float: left;
  width: 77%;
  padding: 14px 10px;
}

.vendor-announcements .msg_title_box span.title {
  font-weight: 700; }

.vendor-announcements .msg_title_box span.title.after_show {
  padding-top: 10px; }

.vendor-announcements .msg_title_box span.mormaltext {
  font-weight: 300;
  overflow: hidden;
  white-space: nowrap;
  margin-top: 4px;
  text-overflow: ellipsis;
  display: inline-block;
  width: 100%; }

.vendor-announcements .msg_arrow_box {
  min-height: 75px;
  padding: 10px;
  width: 8%;
  float: left;
  text-align: center;
  position: relative;
  color: #868686;
  font-size: 16px;
  position: relative; }

.vendor-announcements .msg_arrow_box .msg_stat_click {
  position: absolute;
  top: 50%;
  left: 0;
  right: 0;
  -webkit-transform: translateY(-50%);
      -ms-transform: translateY(-50%);
          transform: translateY(-50%); }

.vendor-announcements .ui-state-default .msg_date_box,
.vendor-announcements .ui-widget-content .ui-state-default .msg_date_box,
.vendor-announcements .ui-widget-header .ui-state-default .msg_date_box,
.vendor-announcements .ui-state-default .msg_title_box,
.vendor-announcements .ui-widget-content .ui-state-default .msg_title_box,
.vendor-announcements .ui-widget-header .ui-state-default .msg_title_box {
  color: #868686 !important; }

.vendor-announcements .ui-widget-content {
  background: #fff none repeat scroll 0 0 !important;
  border: medium none !important;
  color: #333333 !important; }

.vendor-announcements .ui-accordion .ui-accordion-content {
  color: #222;
  font-weight: 300;
  font-size: 15px;
  border: 1px solid #e9e9e9 !important;
  border-top: none !important;
  border-radius: 0 !important;
  padding: 0 !important; }

.vendor-announcements .ui-accordion .ui-accordion-content p:last-of-type {
  margin: 0; }

.vendor-announcements .ui-accordion .ui-accordion-content .wcmp_anouncement-content {
  padding: 30px 5% !important; }

.vendor-announcements .msg_stat {
  min-width: 100px;
  border: 1px solid #dcdcdc;
  background: #f4f4f4;
  position: absolute;
  z-index: 1;
  right: 0;
  top: 70%; }

.vendor-announcements .msg_stat ul {
  list-style: none;
  padding: 0px;
  margin: 0px; }

.vendor-announcements .msg_stat ul li {
  border-bottom: 1px solid #dcdcdc;
  color: #3e3e3e !important;
  font-size: 15px;
  padding: 5px 10px;
  text-align: left; }

.vendor-announcements .msg_stat ul li a {
  color: #3e3e3e !important;
  display: inline-block;
  width: 100%;
  text-decoration: none;
  font-size: 12px; }

.vendor-announcements .ui-state-default .msg_stat ul li a,
.vendor-announcements .ui-state-default .msg_stat ul li a:link,
.vendor-announcements .ui-state-default .msg_stat ul li a:visited {
  color: #3e3e3e !important; }

.vendor-announcements .ui-state-default .msg_stat ul li a:hover,
.vendor-announcements .ui-state-default .msg_stat ul li a.active {
  color: #fc482f !important; }

.vendor-announcements .msg_title_box2 {
  min-height: 60px;
  font-size: 19px;
  float: left;
  width: 90%;
  padding: 20px 33px !important;
  color: #000; }

.vendor-announcements .msg_arrow_box2 {
  min-height: 60px;
  padding: 20px 10px;
  width: 8%;
  float: left;
  text-align: center;
  position: relative;
  color: #868686;
  font-size: 16px; }

.vendor-announcements .university_text {
  color: #000;
  padding: 0px 3px !important;
  font-size: 15px;
  font-weight: 500; }

.vendor-announcements .university_text h3 {
  color: #000;
  font-weight: 700;
  font-size: 15px !important; }

.vendor-announcements .university_text a {
  color: #ff4141 !important;
  font-size: 15px; }

.university_text iframe {
  padding: 30px 0; }

@media (max-width: 767px) {
  .vendor-announcements .msg_arrow_box2 {
    min-height: auto; }

  .vendor-announcements .msg_title_box2 {
    min-height: auto; }

  .vendor-announcements .msg_date_box2 {
    min-height: auto; } }
.wcmp_hide_message, .wcmp_hide_message2, .wcmp_hide_message3, .wcmp_hide_message4 {
  display: none !important; }

.vendor-announcements .ajax_loader_class_msg {
  width: 100%;
  position: absolute;
  z-index: 8888;
  background-color: #ddd;
  opacity: 0.5;
  height: 95%;
  text-align: center;
  display: none; }

.vendor-announcements .ajax_loader_class_msg img {
  margin: 20% auto; }

/*********************** Ledger Report *************************/
#wcmp-vendor-ledger td.debit {
    color: #761919;
}
#wcmp-vendor-ledger td.credit {
    color: #5b841b;
}
#wcmp-vendor-ledger .status {
    text-align: center;
    vertical-align: middle;
}
#wcmp-vendor-ledger .status i {
    display: inline-block;
    width: 24px;
    height: 24px;
    vertical-align: top;
    background: #fec40d;
    z-index: 1;
    border-radius: 50%;
    line-height: 25px;
    text-align: center;
    color: #fff;
}

#wcmp-vendor-ledger .status i.unpaid {
  background: #fec40d; }
#wcmp-vendor-ledger .status i.unpaid:before {
    content: '\e958'; }
#wcmp-vendor-ledger .status i.completed, #wcmp-vendor-ledger .status i.paid {
  background: #37a972; }
#wcmp-vendor-ledger .status i.completed:before, #wcmp-vendor-ledger .status i.paid:before {
    content: '\e950'; }
#wcmp-vendor-ledger .status i.cancelled {
  background: #c84040; }
#wcmp-vendor-ledger .status i.cancelled:before {
    content: '\e94f'; }
#wcmp-vendor-ledger .status i.refunded {
  background: #349bd5; }
#wcmp-vendor-ledger .status i.refunded:before {
    content: '\e959'; }
#wcmp-vendor-ledger .status i.failed {
  background: #f36f59; }
#wcmp-vendor-ledger .status i.failed:before {
    content: '\e954'; }

#wcmp-vendor-ledger td.ref_type {

}

#wcmp-vendor-ledger .ref_type .type.commission {
    background: #c6e1c6;
    color: #5b841b;
}

#wcmp-vendor-ledger .ref_type .type.withdrawal {
    background: #f8dda7;
    color: #94660c
}

#wcmp-vendor-ledger .ref_type .type.refund {
    background: #eba3a3;
    color: #761919
}

#wcmp-vendor-ledger .ref_type .type>span {
    margin: 0 1em;
    overflow: hidden;
    text-overflow: ellipsis
}

.wcmp-vendor-ledger-report-row .ledger-box-wrap {
    margin-bottom: 20px;
}

.wcmp-vendor-ledger-report-row .widget.widget-stats {
    position: relative;
    color: #fff;
    padding: 15px;
    border-radius: 3px;
}
.wcmp-vendor-ledger-report-row .widget.widget-stats h4 { color : #fff; } 
.wcmp-vendor-ledger-report-row .widget.widget-stats .stats-info .number { font-size: large; font-weight: bold; } 
.wcmp-color-scheme-outer_space_blue .wcmp-vendor-ledger-report-row .bg-ledger { background: #3f85b9; }
.wcmp-color-scheme-wild_watermelon .wcmp-vendor-ledger-report-row .bg-ledger{ background: #fd5668; }
.wcmp-color-scheme-old_west .wcmp-vendor-ledger-report-row .bg-ledger { background: #c7a589; }
.wcmp-color-scheme-green_lagoon .wcmp-vendor-ledger-report-row .bg-ledger { background: #009788; }

.wcmp-vendor-ledger-report-row .widget-stats .stats-icon {
    font-size: 42px;
    height: 56px;
    width: 56px;
    text-align: center;
    line-height: 56px;
    margin-left: 15px;
    color: #fff;
    position: absolute;
    right: 15px;
    top: 15px;
    opacity: .5;
}
.wcmp-vendor-ledger-report-row .widget-stats .stats-icon i.wcmp-font { font-weight: 500; }

.vendor-announcements .ui-accordion .ui-accordion-header{
overflow: visible;
}
.vendor-announcements .ui-accordion .ui-accordion-header:after {
content: ".";
display: block;
height: 0;
clear: both;
visibility: hidden;
}

.wcmp_order_items_wrapper table.woocommerce_order_items small.refunded {
    display: block;
    color: #a00;
    white-space: nowrap;
    margin-top: .5em;
}
.wcmp_order_items_wrapper .wcmp-order-totals .refunded-total {
    color: #a00;
}
.wcmp_order_items_wrapper .wcmp-order-totals .amount{
    font-weight: 700;
}
.refund .line_cost{ text-align: right; }
/* Css start */
.navbar-header {
  z-index: 9;
  height: 100%;
  border-right: 1px solid rgb(219, 222, 223);
}
a {text-decoration: unset;}
li.dropdown.login-user .dropdown-toggle::after{
  display: none;}
.sidebar-nav.navbar-collapse .nav li {width: 100%;}
.wcmp-wrapper .panel {
  background: #fff;
  padding: 20px;
  display: block;
  margin-bottom: 20px;
  border-radius: 4px;
}
/* .wcmp-wrapper .panel >div {margin: 0 !important;} */
.wcmp-wrapper .panel >div a{
  margin-bottom: 10px;
  display: inline-block;
}
.datatable-date-filder {
  display: flex;
  align-items: center;}
.dataTables_paginate .pagination {
  justify-content: flex-end;}
.product_search.pull-right{
  text-align: right;}
.table.wcmp-table.shipping-zone-table>thead>tr>th {
  border-bottom: 2px solid #ddd;}
.wcmp_billing_form .form-group, .wcmp_policy_form .form-group, .wcmp_shop_settings_form .form-group{
  display: flex;}
button.wcmp_upload_btn {color: #fff;}
.table {--bs-table-striped-bg: #fff;}
.navbar-header button.navbar-toggler {
  border: none;
  padding: 0 18px;
  height: 100%;}
.navbar-header button.navbar-toggler:focus {
  box-shadow: none;}
.navbar-rightside{
  display: flex;
  justify-content: flex-end;
  align-items:center;
  height: 64px;}
.navbar-leftside {
  display: flex;
  height: 64px;}
  .vendor-orders form[name="wcmp_vendor_dashboard_orders"] {
    display: flex;
}
#wcmp_order_list_form select {
  width: 170px;
}
.product-list-filter-wrap .form-group {
  display: flex;
  justify-content: space-between;
}
.product_search .pro_search_key {
  height: 34px;
}
/* css start */
.form-group .input-group-addon {
  padding: 6px 12px;
  color: #555;
  text-align: center;
  background-color: #eee;
  border: 1px solid #ccc;
  border-radius: 4px 0 0 4px;
  border-right: 0;
}
.panel-body.panel-content-padding {padding: 20px 5px;}
.dataTables_processing {z-index: 9999 !important;}
form.search-pro-by-name-gtin {display: inline-flex;}
#wcmp-edit-product-form #product_data_tabs {width: 100% !important; flex-wrap: unset; border: 0; z-index: 1; position: relative;}
#wcmp-edit-product-form #product_data_tabs li { min-width: fit-content;}
.add-product-info-header {
  display: flex;
  justify-content: space-between;
}
.product-info-tab-wrapper .form-group, .add-product-info-holder .form-group  {display: flex;}
.product-info-tab-wrapper .nav li .nav-link {
background: #bfc3c4;
border: 1px solid #bfc3c4;
padding: 13px 22px;
margin-right: 1px;
color: #383838;
border-radius: 0;
border-top: 2px solid transparent;
}
.product-info-tab-wrapper .nav li .nav-link:hover{  background: #b1becb;}
.product-info-tab-wrapper .nav li .nav-link.active {background: #fff; border-top-color: #3f85b9;  border-bottom-color: #fff;}
.add-coupon-info-holder .form-group {display: flex;  margin: 20px 0;}
.wcmp-wrapper .panel .add-coupon-info-holder .nav-link {margin-bottom: 0; padding: 10px 15px;}
#coupon_data_tabs {margin-left: 15px;}
.wcmp-wrapper .panel .add-coupon-info-holder .nav-link {
margin-bottom: -1px;
padding: 12px 18px;
margin-right: 2px;
border: 1px solid transparent;
border-radius: 4px 4px 0 0;
}
#coupon_data_tabs li .nav-link.active {
color: #555;
cursor: default;
background-color: #fff;
border: 1px solid #ddd;
border-bottom-color: transparent;
}
#wcmp-order-details .panel-body.panel-content-padding {padding: 20px;}
#vendor_ledger_date_filter .form-group { margin-right: 5px;}
#coupon_data_tabs li {min-width: max-content;}



/* //// */
.shipping-zone-list{padding: 0 15px;}
.wcmp-wrapper .panel .shipping-zone-list a {
  display: block;
  margin-bottom: 0;
  border-bottom: 1px solid #d3dbe2;
  padding: 15px 0;
}
.shipping-zone-list hr{display: none;}
.zone-component .form-group {
  padding: 0 15px;
  display: flex;
}

.wcmp-color-scheme-outer_space_blue .wcmp-zone-method-add-btn.show-shipping-methods {
margin: 10px 0 0;
}

.wcmp-zone-method-wrapper .col-md-3.wcmp-zone-method-heading{   
   float: left;
  width: 25%;}
.wcmp-zone-method-wrapper .wcmp-zone-method-content.col-md-9{ float: left; padding-bottom: 15px;}
.wcmp-zone-method-footer.col-md-9.col-sm-9.col-md-offset-3.mt-15 {  margin-left: 25%;}
#shipping-form-fields .form-group .control-label {
  width: 20%;
}
@media screen and (min-width:320px) and (max-width:767px){
.wcmp_shop_settings_form .form-group, .wcmp_policy_form .form-group, .wcmp_billing_form .form-group, form[name='wcmp_vendor_dashboard_stat_report'] .panel-heading {flex-direction: column;}
#vendor_transactions_date_filter .form-group, form[name="wcmp_vendor_dashboard_orders"] .form-group, #vendor_ledger_date_filter .form-group {width: 100%;}
.order-filter-actions .wcmp_black_btn {margin: 5px 0;}
.order-filter-actions #order_bulk_actions, .order-filter-actions #filter_by_order_status {width:100%}
.add-product-info-header, .product-list-filter-wrap .form-group, .add-product-info-holder .form-group {flex-direction: column;}
#wcmp-edit-product-form #product_data_tabs {overflow-x: auto;}
#coupon_data_tabs {
  flex-wrap: unset;
  width: 100%;
  overflow-x: auto;
  margin-left: 0;
}
.side-collapse-container .product_search {display: flex;}
.date-inp-wrap .hasDatepicker { width: 100%; padding-left: 5px;}
form[name="wcmp_vendor_dashboard_orders"] .date-inp-wrap { width: 100%;}
.order-filter-actions select#cide_wise_tax {width: 100%;}
.wcmp-zone-method-wrapper .col-md-3.wcmp-zone-method-heading {
  float: unset; 
   width: auto;
}
.wcmp-zone-method-footer.col-md-9.col-sm-9.col-md-offset-3.mt-15{margin-left:0}
#shipping-form-fields .form-group { flex-direction: column; padding: 0}
#shipping-form-fields .form-group .control-label{ width: auto;}
#shipping-form-fields .form-group .col-md-9.col-sm-9 { padding: 0;}
}
 /* for iphone 5/SE responsive start */
@media screen and (device-aspect-ratio: 40/71){
  #wcmp-order-details .panel.panel-default .panel-heading h3 {font-size: 12px;}
  .change-status .wc-on-hold i {
    background: #ce9416;
    display: flex;
    align-items: center;
    justify-content: center;
    margin: -3px -29px;
}
}
 /* for iphone 5/SE responsive end */

@media screen and (min-width:320px) and (max-width:768px){
  .wcmp-color-scheme-outer_space_blue .sidebar{top: 7px;}
  .wcmp-action-container { top: 69px;right: 20px;}
  .side-collapse-container div.dataTables_wrapper div.dataTables_length {text-align: left;}
}

/* #woocommerce-product-data .product-info-tab-wrapper > .tab-content{border-top: 0;} */